/*-----------------------------------------------------------------------------
 * Name:    Serial.c
 * Purpose: Serial Input Output for Maxim MAX71637
 * Note(s): Possible defines to select the used communication interface:
 *          __UART0  - UART0 interface
 *                   - UART1 is used by default
 *-----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2014 Keil - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "max716xx.h"                   // Device header
#include "Serial.h"

#ifdef __UART0
  #define UARTx     uart(0)
#else
  #define UARTx     uart(1)
#endif


/*-----------------------------------------------------------------------------
 *       SER_Initialize:  Initialize Serial Interface
 *----------------------------------------------------------------------------*/
void SER_Initialize (void) {

  /* enable periph. function for TxD, RxD */  
#ifdef __UART0
  gpio(1)->en_clr = ((1ul << 17) | (1ul << 18));
#else
  gpio(1)->en_clr = ((1ul << 21) | (1ul << 22));    // ?? found out during debugging
#endif
  

  /* 115200 baud, 8 bits, no parity */
  UARTx->brr = UART_BRR0(115200);
  UARTx->rcr = UART_BRR1(115200);

  UARTx->cr = ((1                     << UART_CR_RXTHD_OFST)   |
               (UART_CR_PAREN_DISABLE << UART_CR_PAREN_OFST)   |
               (UART_CR_TXFLUSH_FLUSH << UART_CR_TXFLUSH_OFST) |
               (UART_CR_RXFLUSH_FLUSH << UART_CR_RXFLUSH_OFST) |
               (UART_CR_SIZE_8        << UART_CR_SIZE_OFST)    |
               (UART_CR_RTSCTS_DISABLE<< UART_CR_RTSCTS_OFST)   );

}


/*-----------------------------------------------------------------------------
 *       SER_PutChar:  Write a character to the Serial Port
 *----------------------------------------------------------------------------*/
int32_t SER_PutChar (int32_t c) {

  while (!(UARTx->sr & UART_SR_TXEMPTY_MASK));
  UARTx->dr = c;

  return (c);
}


/*-----------------------------------------------------------------------------
 *       SER_GetChar:  Read a character from the Serial Port (non-blocking)
 *----------------------------------------------------------------------------*/
int32_t SER_GetChar (void) {

  if (!(UARTx->sr & UART_SR_RXEMPTY_MASK)) {
    return (UARTx->dr);
  }

  return (-1);
}
