;/*
; * startup_max716xx.s -- startup code for MAX716XX
; *
; * ----------------------------------------------------------------------------
; * Copyright (c) 2013, Maxim Integrated Products
; * All rights reserved.
; *
; * Redistribution and use in source and binary forms, with or without
; * modification, are permitted provided that the following conditions are met:
; *     * Redistributions of source code must retain the above copyright
; *       notice, this list of conditions and the following disclaimer.
; *     * Redistributions in binary form must reproduce the above copyright
; *       notice, this list of conditions and the following disclaimer in the
; *       documentation and/or other materials provided with the distribution.
; *     * Neither the name of the <organization> nor the
; *       names of its contributors may be used to endorse or promote products
; *       derived from this software without specific prior written permission.
; *
; * THIS SOFTWARE IS PROVIDED BY MAXIM INTEGRATED PRODUCTS ''AS IS'' AND ANY
; * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
; * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
; * DISCLAIMED. IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY
; * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
; * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
; * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
; * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
; * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
; * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
;*/
;                                                             modified by Keil
; to map FreeRTOS function names to their CMSIS equivalents add following lines to FreeRTOSConfig.h 
; #define vPortSVCHandler SVC_Handler
; #define xPortPendSVHandler PendSV_Handler
; #define xPortSysTickHandler SysTick_Handler
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000400

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp                                     ; KEIL: name is fix to be able to use MicroLib


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset
                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors
                EXPORT  __Vectors_End
                EXPORT  __Vectors_Size

                ; Core Level - CM3                ; Most names are to help the FreeRTOS port.
__Vectors       DCD     __initial_sp              ;  0, 0x00 - The initial stack pointer; The stack grows down.
                DCD     Reset_Handler             ;  1, 0x04 - The reset handler
                DCD     NMI_Handler               ;  2, 0x08 - The NMI handler
                DCD     HardFault_Handler         ;  3, 0x0c - The hard fault handler
                DCD     MemManage_Handler         ;  4, 0x10 - The MPU fault handler
                DCD     BusFault_Handler          ;  5, 0x14 - The bus fault handler
                DCD     UsageFault_Handler        ;  6, 0x18 - The usage fault handler
                DCD     0                         ;  7, 0x1c - Reserved
                DCD     0                         ;  8, 0x20 - Reserved
                DCD     0                         ;  9, 0x24 - Reserved
                DCD     0                         ; 10, 0x28 - Reserved
                DCD     SVC_Handler               ; 11, 0x2c - Service call handler
                DCD     DebugMon_Handler          ; 12, 0x30 - Debug monitor handler
                DCD     0                         ; 13, 0x34 - Reserved
                DCD     PendSV_Handler            ; 14, 0x38 - The pending service handler
                DCD     SysTick_Handler           ; 15, 0x3c - The system periodic timer handler

                ; Chip Level - Zeus
                DCD     GPIO0_isr                 ; 16, 0x40 - GPIO 0 interrupt
                DCD     GPIO1_isr                 ; 17, 0x44 - GPIO 1 interrupt
                DCD     tmr0_isr                  ; 18, 0x48 - timer 0 interrupt
                DCD     tmr1_isr                  ; 19, 0x4c - timer 1 interrupt
                DCD     tmr2_isr                  ; 20, 0x50 - timer 2 interrupt
                DCD     tmr3_isr                  ; 21, 0x54 - timer 3 interrupt
                DCD     tmr4_isr                  ; 22, 0x58 - timer 4 interrupt
                DCD     tmr5_isr                  ; 23, 0x5c - timer 5 interrupt
                DCD     tmr6_isr                  ; 24, 0x60 - timer 6 interrupt
                DCD     uart0_isr                 ; 25, 0x64 - UART 0 interrupt
                DCD     uart1_isr                 ; 26, 0x68 - UART 1 interrupt
                DCD     uart2_isr                 ; 27, 0x6c - UART 2 interrupt
                DCD     uart3_isr                 ; 28, 0x70 - UART 3 interrupt
                DCD     uart4_isr                 ; 29, 0x74 - UART 4 interrupt
                DCD     uart5_isr                 ; 30, 0x78 - UART 5 interrupt
                DCD     spi0_isr                  ; 31, 0x7c - SPI 0 interrupt
                DCD     spi1_isr                  ; 32, 0x80 - SPI 1 interrupt
                DCD     i2c0_isr                  ; 33, 0x84 - I2C 0 interrupt
                DCD     sc0_isr                   ; 34, 0x88 - smart card 0 interrupt
                DCD     wdt_isr                   ; 35, 0x8c - watchdog timer interrupt
                DCD     flash_isr                 ; 36, 0x90 - flash controller interrupt
                DCD     mbox_isr                  ; 37, 0x94 - MAXQ mail box interrupt
                DCD     crypto_isr                ; 38, 0x98 - cyptographic module interrupt
                DCD     trng_isr                  ; 39, 0x9c - true random number generator interrupt
                DCD     sspi0_isr                 ; 40, 0xa0 - slave SPI 0 interrupt
                DCD     rpu_isr                   ; 41, 0xa4 - resource protection unit interrupt
                DCD     DMA00_isr                 ; 42, 0xa8 - DMA 0
                DCD     DMA01_isr                 ; 43, 0xac - DMA 1
                DCD     DMA02_isr                 ; 44, 0xb0 - DMA 2
                DCD     DMA03_isr                 ; 45, 0xb4 - DMA 3
                DCD     DMA04_isr                 ; 46, 0xb8 - DMA 4
                DCD     DMA05_isr                 ; 47, 0xbc - DMA 5
                DCD     DMA06_isr                 ; 48, 0xc0 - DMA 6
                DCD     DMA07_isr                 ; 49, 0xc4 - DMA 7
                DCD     DMA08_isr                 ; 50, 0xc8 - DMA 8
                DCD     DMA09_isr                 ; 51, 0xcc - DMA 9
                DCD     DMA10_isr                 ; 52, 0xd0 - DMA 10
                DCD     DMA11_isr                 ; 53, 0xc4 - DMA 11
                DCD     DMA12_isr                 ; 54, 0xc8 - DMA 12
                DCD     DMA13_isr                 ; 55, 0xcc - DMA 13
                DCD     DMA14_isr                 ; 56, 0xc4 - DMA 14
                DCD     DMA15_isr                 ; 57, 0xc8 - DMA 15
                DCD     0                         ; 58, 0xcc - Reserved
                DCD     0                         ; 59, 0xd0 - Reserved
                DCD     0                         ; 60, 0xd4 - Reserved
                DCD     0                         ; 61, 0xd8 - Reserved
                DCD     0                         ; 62, 0xdc - Reserved
                DCD     0                         ; 63, 0xe0 - Reserved
__Vectors_End

__Vectors_Size  EQU  __Vectors_End - __Vectors

                AREA    |.text|, CODE, READONLY

; Reset handler
Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP

; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
MemManage_Handler\
                PROC
                EXPORT  MemManage_Handler         [WEAK]
                B       .
                ENDP
BusFault_Handler\
                PROC
                EXPORT  BusFault_Handler          [WEAK]
                B       .
                ENDP
UsageFault_Handler\
                PROC
                EXPORT  UsageFault_Handler        [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
DebugMon_Handler\
                PROC
                EXPORT  DebugMon_Handler          [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC
                EXPORT  GPIO0_isr                 [WEAK]
                EXPORT  GPIO1_isr                 [WEAK]
                EXPORT  tmr0_isr                  [WEAK]
                EXPORT  tmr1_isr                  [WEAK]
                EXPORT  tmr2_isr                  [WEAK]
                EXPORT  tmr3_isr                  [WEAK]
                EXPORT  tmr4_isr                  [WEAK]
                EXPORT  tmr5_isr                  [WEAK]
                EXPORT  tmr6_isr                  [WEAK]
                EXPORT  uart0_isr                 [WEAK]
                EXPORT  uart1_isr                 [WEAK]
                EXPORT  uart2_isr                 [WEAK]
                EXPORT  uart3_isr                 [WEAK]
                EXPORT  uart4_isr                 [WEAK]
                EXPORT  uart5_isr                 [WEAK]
                EXPORT  spi0_isr                  [WEAK]
                EXPORT  spi1_isr                  [WEAK]
                EXPORT  i2c0_isr                  [WEAK]
                EXPORT  sc0_isr                   [WEAK]
                EXPORT  wdt_isr                   [WEAK]
                EXPORT  flash_isr                 [WEAK]
                EXPORT  mbox_isr                  [WEAK]
                EXPORT  crypto_isr                [WEAK]
                EXPORT  trng_isr                  [WEAK]
                EXPORT  sspi0_isr                 [WEAK]
                EXPORT  rpu_isr                   [WEAK]
                EXPORT  DMA00_isr                 [WEAK]
                EXPORT  DMA01_isr                 [WEAK]
                EXPORT  DMA02_isr                 [WEAK]
                EXPORT  DMA03_isr                 [WEAK]
                EXPORT  DMA04_isr                 [WEAK]
                EXPORT  DMA05_isr                 [WEAK]
                EXPORT  DMA06_isr                 [WEAK]
                EXPORT  DMA07_isr                 [WEAK]
                EXPORT  DMA08_isr                 [WEAK]
                EXPORT  DMA09_isr                 [WEAK]
                EXPORT  DMA10_isr                 [WEAK]
                EXPORT  DMA11_isr                 [WEAK]
                EXPORT  DMA12_isr                 [WEAK]
                EXPORT  DMA13_isr                 [WEAK]
                EXPORT  DMA14_isr                 [WEAK]
                EXPORT  DMA15_isr                 [WEAK]

GPIO0_isr
GPIO1_isr
tmr0_isr
tmr1_isr
tmr2_isr
tmr3_isr
tmr4_isr
tmr5_isr
tmr6_isr
uart0_isr
uart1_isr
uart2_isr
uart3_isr
uart4_isr
uart5_isr
spi0_isr
spi1_isr
i2c0_isr
sc0_isr
wdt_isr
flash_isr
mbox_isr
crypto_isr
trng_isr
sspi0_isr
rpu_isr
DMA00_isr
DMA01_isr
DMA02_isr
DMA03_isr
DMA04_isr
DMA05_isr
DMA06_isr
DMA07_isr
DMA08_isr
DMA09_isr
DMA10_isr
DMA11_isr
DMA12_isr
DMA13_isr
DMA14_isr
DMA15_isr
                B       .
                ENDP


                ALIGN

;*******************************************************************************
; User Stack and Heap initialization
;*******************************************************************************
                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END

;;;;;;;;;;;;;;;;;;;;;;;;;
;; End of file.
;;;;;;;;;;;;;;;;;;;;;;;;;

