/***********************************************************************//**
 * @file ce.h
 * @brief Compute engine addresses of calibration and output variables.
 * @par 
 * This code and information is provided "as is" without warranty of any
 * kind, either expressed or implied, including but not limited to the
 * implied warranties of merchantability and/or fitness for a particular
 * purpose.
 *
 * Copyright (C) 2009 Maxim Integrated Products Inc. All Rights Reserved.
 * DESCRIPTION: 71M65xx POWER METER - CE code constants.
 *
 * $Id: ce.h 21 2013-06-07 23:34:10Z ray.vandewalker $
 **************************************************************************/
#ifndef CE_CONSTANTS_H
#define CE_CONSTANTS_H 1

/** ID of meter equation Wh=VA*IA */
#define EQUATION0 0x00
/** ID of meter equation Wh=(VA/2)*(IA-IB) */
#define EQUATION1 0x20
/** ID of meter equation Wh=VA*IA + VB*IB */
#define EQUATION2 0x40
/** ID of meter equation Wh=VA*IA + VB*UB + VC*IC */
#define EQUATION5 0xA0

// CE locations of note
/** ADC Output for V0 */
#define V0_RAW  0x18

// CE calibration parameters
#define CE_PARM_BASE (CAL_I0)
#define CE_DEFAULT_CNT 0x30 // (1 + (NFREQ-CAL_IO))

/** Gain for I0, 1 = 0x400000 */
#define CAL_I0  0x30    
/** Gain for I1, 1 = 0x400000 */
#define CAL_I1  0x31    
/** Gain for I2, 1 = 0x400000 */
#define CAL_I2  0x32    
/** Gain for I3, 1 = 0x400000 */
#define CAL_I3  0x33    
/** Gain for V0, 1 = 0x400000 */
#define CAL_V0  0x34    
/** Gain for V1, 1 = 0x400000 */
#define CAL_V1  0x35    
/** Gain for V2, 1 = 0x400000 */
#define CAL_V2  0x36    
/** Gain for V3, 1 = 0x400000 */
#define CAL_V3  0x37    
/** Phase for I0, 0 degrees = 0 */
#define PHADJ_0 0x38    
/** Phase for I1, 0 degrees = 0 */
#define PHADJ_1 0x39    
/** Phase for I2, 0 degrees = 0 */
#define PHADJ_2 0x3a    
/** Phase for I3, 0 degrees = 0 */
#define PHADJ_3 0x3b    
/** TEMP_RAW at 22C (Calibrate the base temp.). */
#define TEMP_NOM    0x3c    
/** Temp. slope. */
#define DEGSCALE    0x3d    
/** Vbat_ref compensation / C */
#define PPMC        0x3e    
/** Vbat_ref compensation / C^2 */
#define PPMC2       0x3f    
/** I0SQSUM high offset */
#define QUANT_IA_H  0x40    
/** I0SQSUM low offset */
#define QUANT_IA_L  0x41    
/** I1SQSUM high offset */
#define QUANT_IB_H  0x42    
/** I1SQSUM low offset */
#define QUANT_IB_L  0x43    
/** I2SQSUM high offset */
#define QUANT_IC_H  0x44    
/** I2SQSUM low offset */
#define QUANT_IC_L  0x45    
/** I3SQSUM high offset */
#define QUANT_ID_H  0x46    
/** I3SQSUM low offset */
#define QUANT_ID_L  0x47    
/** V0SQSUM offset */
#define QUANT_VA    0x48    
/** V1SQSUM offset */
#define QUANT_VB    0x49    
/** V2SQSUM offset */
#define QUANT_VC    0x4a    
/** V3SQSUM offset */
#define QUANT_VD    0x4b    
/** W0SUM offset */
#define QUANT_A    0x4c     
/** W1SUM offset */
#define QUANT_B    0x4d     
/** W2SUM offset */
#define QUANT_C    0x4e     
/** Reserved for future use. */
#define QUANT_D    0x4f     
/** VAR0SUM offset */
#define QUANT_VARA    0x50  
/** VAR1SUM offset */
#define QUANT_VARB    0x51  
/** VAR2SUM offset */
#define QUANT_VARC    0x52  
/** Reserved for future use. */
#define QUANT_VARD    0x53  
// - 54, 55, 56, 57
/** Bits to configure the compute engine. */
#define CE_CONFIG     0x58  
/** @addtogroup ceconfig-bits 1 = measure RTC battery. */
#define     TEMP_VBAT_RTC    BIT25  
/** @addtogroup ceconfig-bits 1 = measure battery. */
#define     TEMP_VBAT        BIT24  
/** @addtogroup ceconfig-bits 1 = TBD */
#define     CE_6K_TEMP       BIT23  
/** @addtogroup ceconfig-bits 1 = GAIN_ADJ temp. comp. vars not set by CE. */
#define     EXT_TEMP         BIT22  
/** @addtogroup ceconfig-bits 1 = pulse PULSE_X if zero-crossing. */
#define     DO_EDG_INT       BIT21  
/** @addtogroup ceconfig-bits 1 = pulse PULSE_Y if AC mains power fails. */
#define     DO_SAG_INT       BIT20  
/** @addtogroup ceconfig-bits Delay before AC mains interrupt, in samples */
#define     SAG_CNT_MASK     0x00FFF00    
/** @addtogroup ceconfig-bits Phase no. to measure frequency */
#define     FREQ_SEL_MASK    0x00000C0    
#define     FREQ_SEL_SHIFT   6
/** @addtogroup ceconfig-bits 1 = External power calculation to APULSEW & APULSER */       
#define     EXT_PULSE        BIT5   
/** @addtogroup ceconfig-bits 1 = multiply currents by 8 */
#define     I2_SHUNT         BIT4   
/** @addtogroup ceconfig-bits 1 = use internal creep, on Wh & VARh only */
#define     INT_CREEP        BIT3   
/** @addtogroup ceconfig-bits 1 = Voltages are multipled by 4 */
#define     VG4X             BIT2   
/** @addtogroup ceconfig-bits 1 = increase pulse speed by 16x */
#define     PULSE_FAST       BIT1   
/** @addtogroup ceconfig-bits 1 = decrease pulse speed by 64x */
#define     PULSE_SLOW       BIT0   

/** Pulse rate per KWh, (in special DSP units) */
#define WRATE         0x59  
/** VAR/W conversion ratio */
#define KVAR          0x5a  
/** Measured samples pe raccumulation interval. */
#define CE_SUMPRE     0x5b  
/** Voltage peak threshold for AC mains failure. */
#define SAG_THR       0x5c  
/** Creep threshold, Wh */
#define CREEP_THR     0x5d  
/** I3 Scale */
#define I3_SCALE      0x5e  
/** NFREQ */
#define NFREQ         0x5F
// -
/** Vx temp. gain adjustment, 1 = 0x400000 */
#define GAIN_ADJ0  0x60     
/** IA temp. gain adjustment, 1 = 0x400000 */
#define GAIN_ADJ1  0x61     
/** IB temp. gain adjustment, 1 = 0x400000 */
#define GAIN_ADJ2  0x62     
/** IC temp. gain adjustment, 1 = 0x400000 */
#define GAIN_ADJ3  0x63     
/** IC temp. gain adjustment, 1 = 0x400000 */
#define GAIN_ADJ4  0x64     

/** input to watt pulse. */
#define APULSEW       0x65  
/** input to VAR pulse. */
#define APULSER       0x66  
/** watt pulse counter. */
#define WPULSE_CTR    0x67  
/** var pulse counter. */
#define RPULSE_CTR    0x68  
/** watt pulse accumulator. */
#define WSUM_ACCUM    0x6   
/** watt pulse accumulator II. */
#define WSUM_ACCUM_L  0x6A  
/** var pulse accumulator. */
#define RSUM_ACCUM    0x6B  
/** var pulse accumulator II. */
#define RSUM_ACCUM_L  0x6C  

/** watt pulse fraction. */
#define WPULSE_FRAC   0x6D  
/** var pulse fraction. */
#define RPULSE_FRAC   0x6E  

// CE Output offsets
/** CE's current status bits. */
#define CE_STATUS_X   0x80  
/** 10 * (Current temperature - 23.0 C) */
#define TEMP_X        0x81  
/** Frequency in DSP units. */
#define FREQ_X        0x82  
/** zero crossings in the last accumulation interval. */
#define MAINEDGE_X    0x83  
/** Total Wh in the last accumulation interval. */
#define WSUM_X        0x84
/** Wh in phase A in the last accumulation interval. */
#define W0SUM_X       0x85
/** Wh in phase B in the last accumulation interval. */
#define W1SUM_X       0x86
/** Wh in phase C in the last accumulation interval. */
#define W2SUM_X       0x87
/** Total VARh in the last accumulation interval. */
#define VARSUM_X      0x88
/** VARh in phase A in the last accumulation interval. */
#define VAR0SUM_X     0x89
/** VARh in phase B in the last accumulation interval. */
#define VAR1SUM_X     0x8a
/** VARh in phase C in the last accumulation interval. */
#define VAR2SUM_X     0x8b
/** Total VAh in the last accumulation interval. */
#define VASUM_X       0x8c
/** VAh in phase A in the last accumulation interval. */
#define VA0SUM_X      0x8d
/** VAh in phase B in the last accumulation interval. */
#define VA1SUM_X      0x8e
/** VAh in phase C in the last accumulation interval. */
#define VA2SUM_X      0x8f
/** IA, high 32-bits, in the last accumulation interval. */
#define I0SQSUM_X_H   0x90
/** IA, low 32-bits, in the last accumulation interval. */
#define I0SQSUM_X_L   0x91
/** IB, high 32-bits, in the last accumulation interval. */
#define I1SQSUM_X_H   0x92
/** IB, low 32-bits, in the last accumulation interval. */
#define I1SQSUM_X_L   0x93
/** IC, high 32-bits, in the last accumulation interval. */
#define I2SQSUM_X_H   0x94
/** IC, low 32-bits, in the last accumulation interval. */
#define I2SQSUM_X_L   0x95
/** ID, high 32-bits, in the last accumulation interval. */
#define I3SQSUM_X_H   0x96
/** ID, low 32-bits, in the last accumulation interval. */
#define I3SQSUM_X_L   0x97
/** VA in the last accumulation interval. */
#define V0SQSUM_X     0x98
/** VB in the last accumulation interval. */
#define V1SQSUM_X     0x99
/** VC in the last accumulation interval. */
#define V2SQSUM_X     0x9a
/** DSP's Angle from Phase A to B, X value for atan2().  */
#define PH_AtoB_X     0x9b
/** DSP's Angle from Phase A to C, X value for atan2().  */
#define PH_AtoC_X     0x9c
/** DSP's Angle from Phase A to B, Y value for atan2().  */
#define PH_AtoB2_X    0x9d
/** DSP's Angle from Phase A to C, Y value for atan2().  */
#define PH_AtoC2_X    0x9e      // 2nd arg Y for PH_AtoC = atan2(X,Y)
/** DSP's raw temperature value. */
#define TEMP_RAW_X    0x9f      // ADC output from sensor, avg
/** DSP's battery value. */
#define VBAT_X        0x0A0     // "
/** DSP's battery value of the clock. */
#define VBAT_RTC_X    0x0A1     // "

/***************************************************************************
 * Copyright (C) 2013 Maxim Integrated Products Inc. All Rights Reserved.
 * this program is fully protected by the United States copyright
 * laws and is the property of Maxim Integrated Products Inc.
 ***************************************************************************/
#endif /* CE addresses */
