/*
 * flc_regs.h --
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2012, Maxim Integrated Products
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MAXIM INTEGRATED PRODUCTS ''AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* [INTERNAL] ------------------------------------------------------------------
 * Created on: June 5, 2012
 * Author: Jeremy Brodt
 *
 * ---- Subversion keywords (need to set the keyword property)
 * $Revision: 21 $:  Revision of last commit
 * $Author: ray.vandewalker $:  Author of last commit
 * $Date: 2013-06-07 16:34:10 -0700 (Fri, 07 Jun 2013) $:  Date of last commit
 * [/INTERNAL] -------------------------------------------------------------- */

#ifndef FLC_REGS_H_
#define FLC_REGS_H_

/** @file am62_flc_regs.h FLC Registers Header */

/** @defgroup FLC FLC Driver
 * @ingroup DRIVER
 */


#define FLC_INT_DONE	  0x00000001
#define FLC_INT_AF		  0x00000002
#define FLC_INT_MASK	  0x00000003
#define FLC_INT_DONEIE    0x00000100
#define FLC_INT_AFIE      0x00000200
#define FLC_INT_IEMASK	  0x00000300

#define FLC_CN_PEND	        0x01000000
//B1 silicon is RFU ---#define FLC_CN_STALL_AHB    0x02000000
#define FLC_CN_UNLOCK_MASK  0xF0000000
#define FLC_CN_UNLOCK_VALUE	0x20000000
//#define FLC_CN_PAGE_ERASE   0x02000004
//#define FLC_CN_WORD_WRITE   0x02000001
#define FLC_CN_PAGE_ERASE   0x00000004
#define FLC_CN_WORD_WRITE   0x00000001
#define FLC_CN_PGE_CODE     0x00005500
#define FLC_CN_DSIZE_WORD   0x00000010
#define FLC_CN_BURST_MODE   0x08000000
#define FLC_CN_PREBOOT			0x04000000
#define FLC_CN_M3_FUWEN			0x00010000
#define FLC_CN_M3_FLWEN			0x00020000
#define FLC_CN_M3_FLREN			0x00040000
#define FLC_CN_SPI_FUWEN		0x00100000
#define FLC_CN_SPI_FLWEN		0x00200000
#define FLC_CM_SPI_FLREN		0x00400000


#ifndef __ASSEMBLER__
/* -------------------------------------------------------------------------- */
/** FLC Registers.
 *
 */
typedef volatile struct flc_regs_ {
	unsigned int faddr;  //!< 0x00 Address
	unsigned int fckdiv; //!< 0x04 Clock Divide
	unsigned int fcntl;  //!< 0x08 Control
	unsigned int pr1e;   //!< 0x0C Protected Region 1 End
	unsigned int pr2s;   //!< 0x10 Protected Region 2 Start
	unsigned int pr2e;   //!< 0x14 Protected Region 2 End
	unsigned int pr3s;   //!< 0x18 Protected Region 3 Start
	unsigned int pr3e;   //!< 0x1C Protected Region 3 End
	unsigned int fmode;  //!< 0x20 Mode
	unsigned int fint;   //!< 0x24 Interrupt
	unsigned int rfu0;   //!< 0x28 Reserved
	unsigned int rfu1;   //!< 0x2C Reserved
	unsigned int fdata0; //!< 0x30 Data Reg 0
	unsigned int fdata1; //!< 0x34 Data Reg 1
	unsigned int fdata2; //!< 0x38 Data Reg 2
	unsigned int fdata3; //!< 0x3C Data Reg 3
	unsigned int spicnt; //!< 0x40 Spi Slave Contrl
} flc_regs_t;

#endif /* __ASSEMBLER__ */

/** @} *//* @defgroup AM62_FLC_REGS */

#endif /* FLC_REGS_H_ */
