/*
 * gcr_regs.h --
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2012, Maxim Integrated Products
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MAXIM INTEGRATED PRODUCTS ''AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* [INTERNAL] ------------------------------------------------------------------
 * Created on: June 5, 2012
 * Author: Jeremy Brodt
 *
 * ---- Subversion keywords (need to set the keyword property)
 * $Revision: 229 $:  Revision of last commit
 * $Author: pravin.tanwar $:  Author of last commit
 * $Date: 2013-07-12 13:40:55 -0700 (Fri, 12 Jul 2013) $:  Date of last commit
 * [/INTERNAL] -------------------------------------------------------------- */

#ifndef GCR_REGS_H_
#define GCR_REGS_H_

/** @file gcr_regs.h GCR Registers Header */

/** @defgroup GCR GCR Driver
 * @ingroup DRIVER
 *
 * @note This driver is based on the specification SPEC22H03 \
 * 		AM62 System Controller Rev B
 * */

/** @defgroup GCR_REGS GCR Registers
 *
 *
 *
 * @ingroup GCR
 * @{
 */


/* -------------------------------------------------------------------------- */
/** @defgroup GCR_SCON GCR System Control Register
 *
 * @{
 */

#define GCR_SCON_OFST	0x000		//!< SCON register offset
#define GCR_SCON_DFLT	0x00000000	//!< SCON register default value

#define GCR_SCON_TAPD_OFST		0	//!< TAPD bits offset
#define GCR_SCON_TAPD_MASK		1	//!< TAPD mask
#define GCR_SCON_TAPD_ENABLE	1	//! Disable JTAG TAP pins and allows them to be used as GPIO.
/** @} */ /* @defgroup GCR_SCON */

/* -------------------------------------------------------------------------- */
/** @defgroup GCR_RSTR Reset Register (RSTR)
 *
 * @{
 */

#define GCR_RSTR_OFST					0x004		//!< Reset register offset
#define GCR_RSTR_DFLT					0x00000000	//!< Reset register default value

#define	GCR_RSTR_GPIO_OFST				0
#define	GCR_RSTR_GPIO_MASK_NOOFST		0x1
#define	GCR_RSTR_GPIO_MASK				(GCR_RSTR_GPIO_MASK_NOOFST << GCR_RSTR_GPIO_OFST)

#define	GCR_RSTR_TIMERS_OFST			1
#define	GCR_RSTR_TIMERS_MASK_NOOFST	0x1
#define	GCR_RSTR_TIMERS_MASK			(GCR_RSTR_TIMERS_MASK_NOOFST << GCR_RSTR_TIMERS_OFST)

#define	GCR_RSTR_UARTS_OFST			2
#define	GCR_RSTR_UARTS_MASK_NOOFST		0x1
#define	GCR_RSTR_UARTS_MASK			(GCR_RSTR_UARTS_MASK_NOOFST << GCR_RSTR_UARTS_OFST)

#define	GCR_RSTR_SPI_OFST				3
#define	GCR_RSTR_SPI_MASK_NOOFST		0x1
#define	GCR_RSTR_SPI_MASK				(GCR_RSTR_SPI_MASK_NOOFST << GCR_RSTR_SPI_OFST)

#define	GCR_RSTR_I2C_OFST				4
#define	GCR_RSTR_I2C_MASK_NOOFST		0x1
#define	GCR_RSTR_I2C_MASK				(GCR_RSTR_I2C_MASK_NOOFST << GCR_RSTR_I2C_OFST)

#define	GCR_RSTR_SC_OFST				5
#define	GCR_RSTR_SC_MASK_NOOFST		0x1
#define	GCR_RSTR_SC_MASK				(GCR_RSTR_SC_MASK_NOOFST << GCR_RSTR_SC_OFST)

#define	GCR_RSTR_DMA_OFST				6
#define	GCR_RSTR_DMA_MASK_NOOFST		0x1
#define	GCR_RSTR_DMA_MASK				(GCR_RSTR_DMA_MASK_NOOFST << GCR_RSTR_DMA_OFST)

#define	GCR_RSTR_FLC_OFST				7
#define	GCR_RSTR_FLC_MASK_NOOFST		0x1
#define	GCR_RSTR_FLC_MASK				(GCR_RSTR_DMA_MASK_NOOFST << GCR_RSTR_DMA_OFST)

#define	GCR_RSTR_ICACHE_OFST			8
#define	GCR_RSTR_ICACHE_MASK_NOOFST	0x1
#define	GCR_RSTR_ICACHE_MASK			(GCR_RSTR_DMA_MASK_NOOFST << GCR_RSTR_DMA_OFST)

#define	GCR_RSTR_SPIS_OFST				9
#define	GCR_RSTR_SPIS_MASK_NOOFST		0x1
#define	GCR_RSTR_SPIS_MASK				(GCR_RSTR_SPI_MASK_NOOFST << GCR_RSTR_SPI_OFST)

#define	GCR_RSTR_MAXQ_COM_OFST			10
#define	GCR_RSTR_MAXQ_COM_MASK_NOOFST	0x1
#define	GCR_RSTR_MAXQ_COM_MASK			(GCR_RSTR_SPI_MASK_NOOFST << GCR_RSTR_SPI_OFST)

#define	GCR_RSTR_CRYPTO_OFST			11
#define	GCR_RSTR_CRYPTO_MASK_NOOFST	0x1
#define	GCR_RSTR_CRYPTO_MASK			(GCR_RSTR_CRYPTO_MASK_NOOFST << GCR_RSTR_CRYPTO_OFST)

#define	GCR_RSTR_TRNG_OFST				12
#define	GCR_RSTR_TRNG_MASK_NOOFST		0x1
#define	GCR_RSTR_TRNG_MASK				(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_MAA_OFST				13
#define	GCR_RSTR_MAA_MASK_NOOFST		0x1
#define	GCR_RSTR_MAA_MASK				(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_GCR_OFST				14
#define	GCR_RSTR_GCR_MASK_NOOFST		0x1
#define	GCR_RSTR_GCR_MASK				(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_INTC_OFST				15
#define	GCR_RSTR_INTC_MASK_NOOFST		0x1
#define	GCR_RSTR_INTC_MASK				(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_SIR_OFST				16
#define	GCR_RSTR_SIR_MASK_NOOFST		0x1
#define	GCR_RSTR_SIR_MASK				(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_CRC_OFST				17
#define	GCR_RSTR_CRC_MASK_NOOFST		0x1
#define	GCR_RSTR_CRC_MASK				(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_TEST_OFST				18
#define	GCR_RSTR_TEST_MASK_NOOFST		0x1
#define	GCR_RSTR_TEST_MASK				(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_TRIM_OFST				19
#define	GCR_RSTR_TRIM_MASK_NOOFST		0x1
#define	GCR_RSTR_TRIM_MASK				(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_MAXQ_SHD_OFST			20
#define	GCR_RSTR_MAXQ_SHD_MASK_NOOFST	0x1
#define	GCR_RSTR_MAXQ_SHD_MASK			(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_MAXQ_PAGE_OFST		21
#define	GCR_RSTR_MAXQ_PAGE_MASK_NOOFST	0x1
#define	GCR_RSTR_MAXQ_PAGE_MASK		(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_MAXQ_PROG_OFST		22
#define	GCR_RSTR_MAXQ_PROG_MASK_NOOFST	0x1
#define	GCR_RSTR_MAXQ_PROG_MASK		(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_MAXQ_CE_OFST			23
#define	GCR_RSTR_MAXQ_CE_MASK_NOOFST	0x1
#define	GCR_RSTR_MAXQ_CE_MASK			(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_MAXQ_UTIL_OFST		24
#define	GCR_RSTR_MAXQ_UTIL_MASK_NOOFST	0x1
#define	GCR_RSTR_MAXQ_UTIL_MASK		(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_CACHE_OFST			26
#define	GCR_RSTR_CACHE_MASK_NOOFST		0x1
#define	GCR_RSTR_CACHE_MASK			(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_BRIDGE_OFST			27
#define	GCR_RSTR_BRIDGE_MASK_NOOFST	0x1
#define	GCR_RSTR_BRIDGE_MASK			(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_CM3_OFST				28
#define	GCR_RSTR_CM3_MASK_NOOFST		0x1
#define	GCR_RSTR_CM3_MASK				(GCR_RSTR_TRNG_MASK_NOOFST << GCR_RSTR_TRNG_OFST)

#define	GCR_RSTR_SRST_OFST				29
#define	GCR_RSTR_SRST_MASK_NOOFST		0x1
#define	GCR_RSTR_SRST_MASK				(GCR_RSTR_SRST_MASK_NOOFST << GCR_RSTR_SRST_OFST)

#define	GCR_RSTR_PRST_OFST				30
#define	GCR_RSTR_PRST_MASK_NOOFST		0x1
#define	GCR_RSTR_PRST_MASK				(GCR_RSTR_PRST_MASK_NOOFST << GCR_RSTR_PRST_OFST)

#define	GCR_RSTR_SYSTEM_OFFSET			31 //!< System Reset bit offset
#define	GCR_RSTR_SYSTEM_MASK_NOOFST	0x1
#define	GCR_RSTR_SYSTEM_MASK			(GCR_RSTR_SYSTEM_MASK_NOOFST << GCR_RSTR_SYSTEM_OFFSET) //!< System Reset bit mask
/** @} */ /* @defgroup GCR_RSTR */

/* -------------------------------------------------------------------------- */
/** @defgroup GCR_CLKCN Clock Control Register
 *
 * @li 0-2 HDIV [2:0]: AHB Bus Clock Divider.
 * @li 3-5 PDIV [2:0] Peripheral Bus Clock Divider.
 * @li 6-8 PDIV [2:0] FCLK Divider.
 * @li 9-11 CLKSEL [2:0]: Clock Source Select.
 * @li 13 CKRDY [0]: Clock Ready.
 * @{
 */

#define GCR_CLKCN_OFST	0x008		//!< Clock Control register offset
#define GCR_CLKCN_DFLT	0x00000009	//!< Clock Control register default value

#define GCR_CLKCN_HDIV_OFST	0	//!< HDIV bits offset
#define GCR_CLKCN_PDIV_OFST	3	//!< PDIV bits offset
#define GCR_CLKCN_FDIV_OFST	6	//!< FDIV bits offset
#define GCR_CLKCN_CLKSEL_OFST	9	//!< CLKSEL bits offset
#define GCR_CLKCN_CKRDY_OFST	13	//!< CKRDY bits offset

#define GCR_CLKCN_HDIV_MASK	0x7	//!< HDIV bits offset
#define GCR_CLKCN_PDIV_MASK	0x7	//!< PDIV bits offset
#define GCR_CLKCN_FDIV_MASK	0x7	//!< FDIV bits offset
#define GCR_CLKCN_CLKSEL_MASK	0x7	//!< CLKSEL bits offset
#define GCR_CLKCN_CKRDY_MASK	1	//!< CKRDY bits offset

/** @} */ /* @defgroup GCR_CLKCN */

/* -------------------------------------------------------------------------- */
/** @defgroup GCR_PM Power Management Register (PMR)
 *
 * @{
 */

#define GCR_PMR_OFST		0x00c	//!< Power Mode register offset
#define GCR_PMR_DFLT		0x00000000	//!< Power Mode register default value

#define GCR_PMR_MODE_OFST		0	//!< Power Mode Mode bits offset
#define GCR_PMR_MODE_MASK		3	//!< Power Mode Mode bits mask
#define GCR_PMR_MODE_ACTIVE	0
#define GCR_PMR_MODE_IDLE		1
#define GCR_PMR_MODE_STANDBY	2
#define GCR_PMR_MODE_SHUTDOWN	3

#define GCR_PMR_GPIO_WAKE_OFST	4	//!< Power Mode Mode bits offset
#define GCR_PMR_GPIO_WAKE_MASK	1	//!< Power Mode Mode bits mask
#define GCR_PMR_RTC_WAKE_OFST	5	//!< RTC Wake-up Enable bit offset
#define GCR_PMR_RTC_WAKE_MASK	1	//!< RTC Wake-up Enable bit mask
#define GCR_PMR_PLLPD_OFST     13	//!< PLL Power Down offset
#define GCR_PMR_PLLPD_MASK     1	//!< PLL Power Down mask
/** @} */ /* @defgroup GCR_PM */

/* -------------------------------------------------------------------------- */
/** @defgroup GCR_PLLCN PLL Control Register (PLLCN)
 *
 * @{
 */
#define GCR_PLLCN_OFST					0x014	//!< PLL Control Register offset
#define GCR_PLLCN_DFLT					0x00000000	//!< PLL Control Register default value

#define	GCR_PLLCN_PLL_EN_OFST			0
#define	GCR_PLLCN_PLL_EN_MASK_NOOFST	0x1
#define	GCR_PLLCN_PLL_EN_MASK			(GCR_PLLCN_PLL_EN_MASK_NOOFST << GCR_PLLCN_PLL_EN_OFST)

#define	GCR_PLLCN_PLL_LOCK_OFST		1
#define	GCR_PLLCN_PLL_LOCK_MASK_NOOFST	0x1
#define	GCR_PLLCN_PLL_LOCK_MASK		(GCR_PLLCN_PLL_LOCK_MASK_NOOFST << GCR_PLLCN_PLL_LOCK_OFST)
/** @} */ /* @defgroup GCR_PLLCN */

/* -------------------------------------------------------------------------- */
/** @defgroup GCR_PERCKCN GCR Peripheral Clock Disable Register
 *
 * @{
 */

#define GCR_PERCKCN_OFST	0x024		//!< PERCKCN register offset
#define GCR_PERCKCN_DFLT	0x00000000	//!< PERCKCN register default value

/** @} */ /* @defgroup GCR_PERCKCN */

/* -------------------------------------------------------------------------- */
/** @defgroup GCR_MEMCKCN GCR Memory Clock Disable Register
 *
 * @{
 */

#define GCR_MEMCKCN_OFST	0x028		//!< MEMCKCN register offset
#define GCR_MEMCKCN_DFLT	0x00000000	//!< MEMCKCN register default value

/** @} */ /* @defgroup GCR_MEMCKCN */

/* -------------------------------------------------------------------------- */
/** @defgroup GCR_MEMZCN GCR Memory Zeroize Control Register
 *
 * @{
 */

#define GCR_MEMZCN_OFST	0x02C		//!< MEMZCN register offset
#define GCR_MEMZCN_DFLT	0x00000000	//!< MEMZCN register default value

/** @} */ /* @defgroup GCR_MEMZCN */

/* -------------------------------------------------------------------------- */
/** @defgroup GCR_MEMPD GCR Memory Power Down Register
 *
 * @{
 */

#define GCR_MEMPD_OFST	0x030		//!< MEMPD register offset
#define GCR_MEMPD_DFLT	0x00000000	//!< MEMPD register default value

/** @} */ /* @defgroup GCR_MEMPD */

/* -------------------------------------------------------------------------- */
/** @defgroup GCR_SCCK GCR Smart Card Clock Control Register
 *
 * @{
 */

#define GCR_SCCK_OFST	0x034		//!< SCCK register offset
#define GCR_SCCK_DFLT	0x00000000	//!< SCCK register default value

/** @} */ /* @defgroup GCR_SCCK */


#ifndef __ASSEMBLER__

/* -------------------------------------------------------------------------- */

/** GCR Registers.
 *
 */
typedef volatile struct _gcr_regs_{
	unsigned scon;		//!< 0x0 System Control Register
	unsigned rstr;		//!< 0x4 Clock dividers register
	unsigned clkcn;		//!< 0x8 Clock Control Register
	unsigned pmr;		//!< 0xc Power Management Register
	unsigned gap1;		// 0x10 JHC addition
	unsigned pllcn;     //!< 0x14 PLL Control Register
	unsigned pckdiv;	//!< 0x18 Peripheral clock divider register
	unsigned rfu0;		//!< 0x1c For alignment
	unsigned rfu1;		// 0x20 Reserved for platform
	unsigned perckcn;	//!< 0x24 Peripheral Clock Control Register
	unsigned memclk_dis; //!< 0x28 Memory Clock Disable Register
	unsigned memzcn;	//!< 0x2c Memory Zeroize Control Register
	unsigned mempd;		//!< 0x30 Memory Power Down Register
	unsigned scck;		//!< 0x34 Smart Card Clock Control Register
	unsigned pwst;		//!< 0x38 Power status register
    unsigned rfu2[31];
    unsigned info;      //!< 0x100 Info register

} gcr_regs_t;

/** GCR devices
 *
 */
typedef enum _gcr_dev_ {
/* TODO */
	GCR_DEV_GPIO0 = 0,
#if 0
	GCR_DEV_ADC = 0,	//! Disables the ADC clock.
	GCR_DEV_SD,		//! Disables the SDC clock.
	GCR_DEV_USB0,		//! Disables the USB0 clock.
	GCR_DEV_USB1,		//! Disables the USB1 clock.
	GCR_DEV_TPR,		//! Disables the Thermal Printer clock.
	GCR_DEV_SPI0,		//! Disables the SPI0 clock.
	GCR_DEV_SPI1,		//! Disables the SPI1 clock.
	GCR_DEV_SPI2,		//! Disables the SPI2 clock.
	GCR_DEV_SPI3,		//! Disables the SPI3 clock.
	GCR_DEV_SPI4,		//! Disables the SPI4 clock.
	GCR_DEV_UART0,		//! Disables the USART0 clock.
	GCR_DEV_UART1,		//! Disables the USART1 clock.
	GCR_DEV_UART2,		//! Disables the USART2 clock.
	GCR_DEV_SC0,		//! Disables the Smart Card 0 clock.
	GCR_DEV_SC1,		//! Disables the Smart Card 1 clock.
	GCR_DEV_I2C,		//! Disables the I2C clock.
	GCR_DEV_CRC,		//! Disables the CRC clock.
	GCR_DEV_TMR0,		//! Disables the Timer 0 clock.
	GCR_DEV_TMR1,		//! Disables the Timer 1 clock.
	GCR_DEV_TMR2,		//! Disables the Timer 2 clock.
	GCR_DEV_EMAC,		//! Disables the Ethernet MAC clock.
	GCR_DEV_TFT,		//! Disables the LCD and TFT clocks.
#endif
	GCR_DEV_ALL = -1	//!< All devices
} gcr_dev_t;

/** System Frequencies
 *
 */
typedef enum _gcr_sysfreq_ {
	GCR_SYSFREQ_150MHZ = 0x0,	//!< System at 150MHz
/* TODO */
#if 0
	GCR_SYSFREQ_384MHZ = 0x0,	//!< System at 384MHz
	GCR_SYSFREQ_192MHZ,		//!< System at 192MHz
	GCR_SYSFREQ_96MHZ,			//!< System at 96MHz
	GCR_SYSFREQ_48MHZ,			//!< System at 48MHz
	GCR_SYSFREQ_24MHZ,			//!< System at 24MHz
	GCR_SYSFREQ_12MHZ			//!< System at 12MHz
#endif
} gcr_sysfreq_t;

/** Operating Mode
 *
 */
typedef enum _gcr_powermode_ {
	GCR_PM_MODE_ACTIVE = 0,	//!< Active mode configuration
	GCR_PM_MODE_IDLE,			//!< Idle mode configuration
	GCR_PM_MODE_STANDBY,		//!< Lowest power consumption mode
	GCR_PM_MODE_SHUTDOWN		//!< Similar to STANDY mode but without wakeup possibility
} gcr_powermode_t;

#endif /* __ASSEMBLER__ */

/** @} */ /* @defgroup GCR_REGS */

#endif /* GCR_REGS_H_ */
