/*
 * intc_regs.h --
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2012, Maxim Integrated Products
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MAXIM INTEGRATED PRODUCTS ''AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* [INTERNAL] ------------------------------------------------------------------
 * Created on: June 5, 2012
 * Author: Jeremy Brodt
 *
 * ---- Subversion keywords (need to set the keyword property)
 * $Revision: 21 $:  Revision of last commit
 * $Author: ray.vandewalker $:  Author of last commit
 * $Date: 2013-06-07 16:34:10 -0700 (Fri, 07 Jun 2013) $:  Date of last commit
 * [/INTERNAL] -------------------------------------------------------------- */

#ifndef INTC_REGS_H_
#define INTC_REGS_H_

#include "nvic_regs.h"

/** @file intc_regs.h INTC Registers Header */

/** @defgroup INTC INTC Driver
 * @ingroup DRIVER
 */

/** @defgroup INTC_REGS INTC Registers
 *
 * @note INTC IP or Specification version number
 *
 * @ingroup INTC
 * @{
 */

/*
 * INTC Registers
 */
#define INTC_EN0_SET_OFST		NVIC_ISER0_OFST
#define INTC_EN0_CLR_OFST		NVIC_ICER0_OFST	
#define INTC_EN1_SET_OFST		NVIC_ISER1_OFST
#define INTC_EN1_CLR_OFST		NVIC_ICER1_OFST	
#define INTC_SW_INT0_SET_OFST	NVIC_ISPR0_OFST
#define INTC_SW_INT0_CLR_OFST	NVIC_ICPR0_OFST
#define INTC_SW_INT1_SET_OFST	NVIC_ISPR1_OFST
#define INTC_SW_INT1_CLR_OFST	NVIC_ICPR1_OFST
#define INTC_INT0_STAT_OFST		NVIC_ISPR0_OFST
#define INTC_INT1_STAT_OFST		NVIC_ISPR0_OFST
#define INTC_RAW0_INT_STAT_OFST	NVIC_ISPR0_OFST
#define INTC_RAW1_INT_STAT_OFST	NVIC_ISPR0_OFST

/** @} */

#ifndef __ASSEMBLER__
/** INTC Registers.
 *
 */
typedef nvic_regs_t intc_regs_t;

/** Interruption Priorities
 */
typedef nvic_prio_t intc_prio_t;

#define INTC_PRIO_OFST		4
#define INTC_PRIO_MASK		0xF0
#define INTC_SET_PRIO(priority) ((priority)<<(INTC_PRIO_OFST))

#define INTC_PRIO_0	INTC_SET_PRIO(0)	//!< Priority 0 (Highest)
#define INTC_PRIO_1	INTC_SET_PRIO(1)	//!< Priority 1
#define INTC_PRIO_2	INTC_SET_PRIO(2)	//!< Priority 2
#define INTC_PRIO_3	INTC_SET_PRIO(3)	//!< Priority 3
#define INTC_PRIO_4	INTC_SET_PRIO(4)	//!< Priority 4
#define INTC_PRIO_5	INTC_SET_PRIO(5)	//!< Priority 5
#define INTC_PRIO_6	INTC_SET_PRIO(6)	//!< Priority 6
#define INTC_PRIO_7	INTC_SET_PRIO(7)	//!< Priority 7
#define INTC_PRIO_8	INTC_SET_PRIO(8)	//!< Priority 8
#define INTC_PRIO_9	INTC_SET_PRIO(9)	//!< Priority 9
#define INTC_PRIO_10	INTC_SET_PRIO(10)	//!< Priority 10
#define INTC_PRIO_11	INTC_SET_PRIO(11)	//!< Priority 11
#define INTC_PRIO_12	INTC_SET_PRIO(12)	//!< Priority 12
#define INTC_PRIO_13	INTC_SET_PRIO(13)	//!< Priority 13
#define INTC_PRIO_14	INTC_SET_PRIO(14)	//!< Priority 14
#define INTC_PRIO_15	INTC_SET_PRIO(15)	//!< Priority 15 (Lowest)

#if USE_HIGH_VECTORS == 1
extern unsigned long __section_start_vectors;
#define vectors		(&__section_start_vectors)
#endif

#endif /* __ASSEMBLER__ */

/** @} */ /* @defgroup INTC_REGS */

#endif /* INTC_REGS_H_ */

