/*
 * max716xx.h --
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2012, Maxim Integrated Products
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MAXIM INTEGRATED PRODUCTS ''AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *                                                             modified by Keil
 */

/* [INTERNAL] ------------------------------------------------------------------
 * Created on: June 1, 2012
 * Author: Jeremy Brodt
 *
 * ---- Subversion keywords (need to set the keyword property)
 * $Revision: 839 $:  Revision of last commit
 * $Author: pravin.tanwar $:  Author of last commit
 * $Date: 2013-12-19 15:51:35 -0800 (Thu, 19 Dec 2013) $:  Date of last commit
 * [/INTERNAL] -------------------------------------------------------------- */

#ifndef MAX716XX_H
#define MAX716XX_H

#ifndef __MAX716XX__
#define __MAX716XX__ 1
#endif

/** @defgroup MAX716XX MAX716XX
 * @{
 */
 
//--- Keil ---------------------
/** @addtogroup Configuration_of_CMSIS
  * @{
  */

/** Interrupt Number Definition */
typedef enum IRQn
{
/******  Cortex-M3 Processor Exceptions Numbers ****************************************************/
  NonMaskableInt_IRQn           = -14,       /*!< 2 Non Maskable Interrupt                         */
  MemoryManagement_IRQn         = -12,       /*!< 4 Cortex-M3 Memory Management Interrupt          */
  BusFault_IRQn                 = -11,       /*!< 5 Cortex-M3 Bus Fault Interrupt                  */
  UsageFault_IRQn               = -10,       /*!< 6 Cortex-M3 Usage Fault Interrupt                */
  SVCall_IRQn                   = -5,        /*!< 11 Cortex-M3 SV Call Interrupt                   */
  DebugMonitor_IRQn             = -4,        /*!< 12 Cortex-M3 Debug Monitor Interrupt             */
  PendSV_IRQn                   = -2,        /*!< 14 Cortex-M3 Pend SV Interrupt                   */
  SysTick_IRQn                  = -1,        /*!< 15 Cortex-M3 System Tick Interrupt               */

/******  MAX716xx Specific Interrupt Numbers *******************************************************/
  GPIO0_IRQn                    =  0,        /*!< GPIO 0 interrupt                                 */
  GPIO1_IRQn                    =  1,        /*!< GPIO 1 interrupt                                 */
  TMR0_IRQn                     =  2,        /*!< timer 0 interrupt                                */
  TMR1_IRQn                     =  3,        /*!< timer 1 interrupt                                */
  TMR2_IRQn                     =  4,        /*!< timer 2 interrupt                                */
  TMR3_IRQn                     =  5,        /*!< timer 3 interrupt                                */
  TMR4_IRQn                     =  6,        /*!< timer 4 interrupt                                */
  TMR5_IRQn                     =  7,        /*!< timer 5 interrupt                                */
  TMR6_IRQn                     =  8,        /*!< timer 6 interrupt                                */
  UART0_IRQn                    =  9,        /*!< UART 0 interrupt                                 */
  UART1_IRQn                    = 10,        /*!< UART 1 interrupt                                 */
  UART2_IRQn                    = 11,        /*!< UART 2 interrupt                                 */
  UART3_IRQn                    = 12,        /*!< UART 3 interrupt                                 */
  UART4_IRQn                    = 13,        /*!< UART 4 interrupt                                 */
  UART5_IRQn                    = 14,        /*!< UART 5 interrupt                                 */
  SPI0_IRQn                     = 15,        /*!< SPI 0 interrupt                                  */
  SPI1_IRQn                     = 16,        /*!< SPI 1 interrupt                                  */
  I2C_IRQn                      = 17,        /*!< I2C 0 interrupt                                  */
  SC_IRQn                       = 18,        /*!< smart card 0 interrupt                           */
  WDT_IRQn                      = 19,        /*!< Watchdog interrupt                               */
  FLC_IRQn                      = 20,        /*!< flash controller interrupt                       */
  MAXQ_COM_IRQn                 = 21,        /*!< MAXQ mail box interrupt                          */
  CRYPTO_IRQn                   = 22,        /*!< cyptographic module interrupt                    */
  TRNG_IRQn                     = 23,        /*!< true random number generator interrupt           */
  SPIS_IRQn                     = 24,        /*!< slave SPI 0 interrupt                            */
  RPU_IRQn                      = 25,        /*!< resource protection unit interrupt               */
  DMA0_IRQn                     = 26,        /*!< DMA  0 interrupt                                 */
  DMA1_IRQn                     = 27,        /*!< DMA  1 interrupt                                 */
  DMA2_IRQn                     = 28,        /*!< DMA  2 interrupt                                 */
  DMA3_IRQn                     = 29,        /*!< DMA  3 interrupt                                 */
  DMA4_IRQn                     = 30,        /*!< DMA  4 interrupt                                 */
  DMA5_IRQn                     = 31,        /*!< DMA  5 interrupt                                 */
  DMA6_IRQn                     = 32,        /*!< DMA  6 interrupt                                 */
  DMA7_IRQn                     = 33,        /*!< DMA  7 interrupt                                 */
  DMA8_IRQn                     = 34,        /*!< DMA  8 interrupt                                 */
  DMA9_IRQn                     = 35,        /*!< DMA  9 interrupt                                 */
  DMA10_IRQn                    = 36,        /*!< DMA 10 interrupt                                 */
  DMA11_IRQn                    = 37,        /*!< DMA 11 interrupt                                 */
  DMA12_IRQn                    = 38,        /*!< DMA 12 interrupt                                 */
  DMA13_IRQn                    = 39,        /*!< DMA 13 interrupt                                 */
  DMA14_IRQn                    = 40,        /*!< DMA 14 interrupt                                 */
  DMA15_IRQn                    = 41         /*!< DMA 15 interrupt                                 */
} IRQn_Type;

/** Processor and Core Peripheral Section */

/* Configuration of the Cortex-M4 Processor and Core Peripherals */
#define __CM3_REV              0x0201       /*!< Cortex-M3 Core Revision                           */
#define __MPU_PRESENT             0         /*!< MPU present or not                                */
#define __NVIC_PRIO_BITS          3         /*!< Number of Bits used for Priority Levels           */
#define __Vendor_SysTickConfig    0         /*!< Set to 1 if different SysTick Config is used      */
#define __FPU_PRESENT             0         /*!< FPU present or not                                */

/** @} */ /* End of group Configuration_of_CMSIS */

#include <core_cm3.h>                       /*!< Cortex-M0 processor and core peripherals */
#include "system_max716xx.h"                /*!< MAX716xx System                          */
//--- Keil end -----------------

/** @defgroup MEM MAX716XX peripheral clock
 * @{
 */

#ifndef FPGA_EMULATOR
#define PCLK_HZ        (108134400 / 2)    // MAX716XX real silicon
#else
#define PCLK_HZ        20000000           // MAX716XX emulator
#endif

/** @defgroup MEM MAX716XX Memories
 * @{
 */

#define MEM_FLASH_BASE      0x00000000          //!< MAX716XX Flash base address
#define MEM_FLASH_SIZE      0x100000            //!< MAX716XX Flash size (1MB)
#define FLASH_BASE          MEM_ROM_BASE        //!< ROM base address
#define FLASH_SIZE          MEM_ROM_SIZE        //!< ROM size
#define INFO_BLK_BASE       0x00100000          //!< MAX716XX Info block base addr
#define INFO_BLK_SIZE       0x0004000           //!< MAX716XX Info block size
#define MEM_CODE_RAM_BASE   0x400000            //!< MAX716XX code RAM base address
#define MEM_CODE_RAM_SIZE   0x10000             //!< MAX716XX code RAM size (64KB)
#define CODE_RAM_BASE       MEM_CODE_RAM_BASE   //!< code RAM base address
#define CODE_RAM_SIZE       MEM_CODE_RAM_SIZE   //!< code RAM size
#define MEM_RAM_BASE        0x20000000          //!< MAX716XX RAM base address
#define MEM_RAM_SIZE        0x10000             //!< MAX716XX RAM size (64KB)
#define RAM_BASE            MEM_RAM_BASE        //!< RAM base address
#define RAM_SIZE            MEM_RAM_SIZE        //!< RAM size

/** @} */
/* ========================================================================== */
/** @defgroup INFO block MAX716XX infoblock
 * @{
 */


/** @} */
/* ========================================================================== */
/** @defgroup IO MAX716XX IOs
 * @{
 */

#ifndef __ASSEMBLY__
/** Convert PA to VA. */
#  define IO_ADDRESS(x) ((unsigned char *)(x))
#  define PFM(x)        (x)

#else
/** Convert PA to VA. */
#  define IO_ADDRESS(x) (x)
#endif /* __ASSEMBLY__ */


#define IOBASE      0x40000000          //!< APB IO Physical Base Address
#define IOBASE_ADDR IO_ADDRESS(IOBASE)  //!< APB IO Virtual Base Address

/* -------------------------------------------------------------------------- */
/** @defgroup MAX716XX IO Ports
 *
 * Offsets.
 * @{
 */

#define GPIO0_PORT      0x000000    //! GPIO 0
#define GPIO1_PORT      0x001000    //! GPIO 1
#define TMR0_PORT       0x010000    //! PWM Timers 0
#define TMR1_PORT       0x011000    //! PWM Timers 1
#define TMR2_PORT       0x012000    //! PWM Timers 2
#define TMR3_PORT       0x013000    //! PWM Timers 3
#define TMR4_PORT       0x014000    //! PWM Timers 4
#define TMR5_PORT       0x015000    //! PWM Timers 5
#define TMR6_PORT       0x016000    //! PWM Timers 6
#define UART0_PORT      0x020000    //! UART 0
#define UART1_PORT      0x021000    //! UART 1
#define UART2_PORT      0x022000    //! UART 2
#define UART3_PORT      0x023000    //! UART 3
#define UART4_PORT      0x024000    //! UART 4
#define UART5_PORT      0x025000    //! UART 5
#define SPI0_PORT       0x028000    //! SPI 0
#define SPI1_PORT       0x029000    //! SPI 1
#define I2C_PORT        0x030000    //! I2C
#define SC_PORT         0x038000    //! Smart Card
#define WDG_PORT		0x040000	//!WDOG
#define DMA_PORT        0x060000    //! DMA
#define FLC_PORT        0x061000    //! Flash Controller
#define ICACHE_PORT     0x062000    //! Cache Controller
#define SPIS_PORT       0x063000    //! SPI Slave
#define MAXQ_COM_PORT   0x064000    //! DSP Mail Box

#define CRYPTO_PORT     0x070000    //! Crypto Engine
#define TRNG_PORT       0x071000    //! TRNG
#define MAA_PORT        0x072000    //! MAA Memory

#define GCR_PORT        0x0A0000    //! GCR
#define RPU_PORT		0x0A1000	//!RPU
#define SIR_PORT        0x0A2000    //! SIR
#define CRC_PORT        0x0A3000    //! CRC
#define TEST_PORT       0x0A4000    //! TEST
#define TRIM_PORT       0x0A5000    //! Trim

#define MAXQ_SHD_MEM_PORT   0x100000    //! 1024x32
#define MAXQ_PAGE_MEM_PORT  0x110000    //! 4096x32
#define MAXQ_PROG_MEM_PORT  0x120000    //! 4096x32
#define MAXQ_CE_MEM_PORT    0x130000    //! 4096x32
#define MAXQ_UTIL_MEM_PORT  0x140000    //! 4096x32

#define MAXQ_SHD_MEM_SIZE   0x1000  //! 1024x32 (4KB)
#define MAXQ_PAGE_MEM_SIZE  0x4000  //! 4096x32 (16KB)
#define MAXQ_PROG_MEM_SIZE  0x10000   //! 16384x32 (64KB)
#define MAXQ_CE_MEM_SIZE    0x4000  //! 4096x32 (16KB)
#define MAXQ_UTIL_MEM_SIZE  0x4000  //! 4096x32 (16KB)


/** @} */
/* -------------------------------------------------------------------------- */
/** @defgroup IOBASE MAX716XX IO Addresses
 * @{
 */

#define GPIO0_IOBASE (IOBASE + GPIO0_PORT) //! GPIO 0 Address
#define GPIO1_IOBASE (IOBASE + GPIO1_PORT) //! GPIO 1 Address
#define TMR0_IOBASE  (IOBASE + TMR0_PORT)  //! PWM Timers 0 Address
#define TMR1_IOBASE  (IOBASE + TMR1_PORT)  //! PWM Timers 1 Address
#define TMR2_IOBASE  (IOBASE + TMR2_PORT)  //! PWM Timers 2 Address
#define TMR3_IOBASE  (IOBASE + TMR3_PORT)  //! PWM Timers 3 Address
#define TMR4_IOBASE  (IOBASE + TMR4_PORT)  //! PWM Timers 4 Address
#define TMR5_IOBASE  (IOBASE + TMR5_PORT)  //! PWM Timers 5 Address
#define TMR6_IOBASE  (IOBASE + TMR6_PORT)  //! PWM Timers 6 Address
#define UART0_IOBASE (IOBASE + UART0_PORT) //! UART 0 Address
#define UART1_IOBASE (IOBASE + UART1_PORT) //! UART 1 Address
#define UART2_IOBASE (IOBASE + UART2_PORT) //! UART 2 Address
#define UART3_IOBASE (IOBASE + UART3_PORT) //! UART 3 Address
#define UART4_IOBASE (IOBASE + UART4_PORT) //! UART 4 Address
#define UART5_IOBASE (IOBASE + UART5_PORT) //! UART 5 Address
#define SPI0_IOBASE  (IOBASE + SPI0_PORT)  //! SPI 0 Address
#define SPI1_IOBASE  (IOBASE + SPI1_PORT)  //! SPI 1 Address
#define I2C_IOBASE   (IOBASE + I2C_PORT)   //! I2C Address
#define SC_IOBASE    (IOBASE + SC_PORT)    //! Smart Card Address
#define WDG_IOBASE	 (IOBASE + WDG_PORT)   //!Watchdog Address
#define DMA_IOBASE   (IOBASE + DMA_PORT)   //! DMA Address
#define FLC_IOBASE   (IOBASE + FLC_PORT)   //! Flash Controller Address
#define ICACHE_IOBASE (IOBASE + ICACHE_PORT)//! Cache Controller Address
#define SPIS_IOBASE  (IOBASE + SPIS_PORT)  //! SPI Slave Address
#define MAXQ_COM_IOBASE (IOBASE + MAXQ_COM_PORT)  //! DSP Mail Box Address

#define CRYPTO_IOBASE (IOBASE + CRYPTO_PORT)//! Crypto Engine Address
#define TRNG_IOBASE  (IOBASE + TRNG_PORT)  //! TRNG Address
#define MAA_IOBASE   (IOBASE + MAA_PORT)   //! MAA Memory Address

#define GCR_IOBASE   (IOBASE + GCR_PORT)   //! GCR Address
#define RPU_IOBASE	 (IOBASE + RPU_PORT)   //! RPU Address
#define SIR_IOBASE   (IOBASE + SIR_PORT)   //! SIR Address
#define CRC_IOBASE   (IOBASE + CRC_PORT)   //! CRC Address
#define TEST_IOBASE  (IOBASE + TEST_PORT)  //! TEST Address
#define TRIM_IOBASE  (IOBASE + TRIM_PORT)  //! Trim Address

#define MAXQ_SHD_MEM_IOBASE  (IOBASE + MAXQ_SHD_MEM_PORT)  //! 1024x32 Address
#define MAXQ_PAGE_MEM_IOBASE (IOBASE + MAXQ_PAGE_MEM_PORT) //! 4096x32 Address
#define MAXQ_PROG_MEM_IOBASE (IOBASE + MAXQ_PROG_MEM_PORT) //! 4096x32 Address
#define MAXQ_CE_MEM_IOBASE   (IOBASE + MAXQ_CE_MEM_PORT)   //! 4096x32 Address
#define MAXQ_UTIL_MEM_IOBASE (IOBASE + MAXQ_UTIL_MEM_PORT) //! 4096x32 Address

/** @} */
/* -------------------------------------------------------------------------- */
/** @defgroup IOMEM MAX716XX IO Virtual Addresses
 * @{
 */

#define GPIO0_IOMEM     IO_ADDRESS(GPIO0_IOBASE)    //! GPIO 0 Address
#define GPIO1_IOMEM     IO_ADDRESS(GPIO1_IOBASE)    //! GPIO 1 Address
#define TMR0_IOMEM      IO_ADDRESS(TMR0_IOBASE)     //! PWM Timers 0 Address
#define TMR1_IOMEM      IO_ADDRESS(TMR1_IOBASE)     //! PWM Timers 1 Address
#define TMR2_IOMEM      IO_ADDRESS(TMR2_IOBASE)     //! PWM Timers 2 Address
#define TMR3_IOMEM      IO_ADDRESS(TMR3_IOBASE)     //! PWM Timers 3 Address
#define TMR4_IOMEM      IO_ADDRESS(TMR4_IOBASE)     //! PWM Timers 4 Address
#define TMR5_IOMEM      IO_ADDRESS(TMR5_IOBASE)     //! PWM Timers 5 Address
#define TMR6_IOMEM      IO_ADDRESS(TMR6_IOBASE)     //! PWM Timers 6 Address
#define UART0_IOMEM     IO_ADDRESS(UART0_IOBASE)    //! UART 0 Address
#define UART1_IOMEM     IO_ADDRESS(UART1_IOBASE)    //! UART 1 Address
#define UART2_IOMEM     IO_ADDRESS(UART2_IOBASE)    //! UART 2 Address
#define UART3_IOMEM     IO_ADDRESS(UART3_IOBASE)    //! UART 3 Address
#define UART4_IOMEM     IO_ADDRESS(UART4_IOBASE)    //! UART 4 Address
#define UART5_IOMEM     IO_ADDRESS(UART5_IOBASE)    //! UART 5 Address
#define SPI0_IOMEM      IO_ADDRESS(SPI0_IOBASE)     //! SPI 0 Address
#define SPI1_IOMEM      IO_ADDRESS(SPI1_IOBASE)     //! SPI 1 Address
#define I2C_IOMEM       IO_ADDRESS(I2C_IOBASE)      //! I2C Address
#define SC_IOMEM        IO_ADDRESS(SC_IOBASE)       //! Smart Card Address
#define WDG_IOMEM		IO_ADDRESS(WDG_IOBASE)		//! WDOG Address
#define DMA_IOMEM       IO_ADDRESS(DMA_IOBASE)      //! DMA Address
#define FLC_IOMEM       IO_ADDRESS(FLC_IOBASE)      //! Flash Controller Address
#define ICACHE_IOMEM    IO_ADDRESS(ICACHE_IOBASE)   //! Cache Controller Address
#define SPIS_IOMEM      IO_ADDRESS(SPIS_IOBASE)     //! SPI Slave Address
#define MAXQ_COM_IOMEM  IO_ADDRESS(MAXQ_COM_IOBASE) //! DSP Mail Box Address

#define CRYPTO_IOMEM    IO_ADDRESS(CRYPTO_IOBASE)   //! Crypto Engine Address
#define TRNG_IOMEM      IO_ADDRESS(TRNG_IOBASE)     //! TRNG Address
#define MAA_IOMEM       IO_ADDRESS(MAA_IOBASE)      //! MAA Memory Address

#define GCR_IOMEM       IO_ADDRESS(GCR_IOBASE)      //! GCR Address
#define RPU_IOMEM		IO_ADDRESS(RPU_IOBASE)		//! RPU Address
#define SIR_IOMEM       IO_ADDRESS(SIR_IOBASE)      //! SIR Address
#define CRC_IOMEM       IO_ADDRESS(CRC_IOBASE)      //! SIR Address
#define TEST_IOMEM      IO_ADDRESS(TEST_IOBASE)     //! TEST Address
#define TRIM_IOMEM      IO_ADDRESS(TRIM_IOBASE)     //! Trim Address

#define MAXQ_SHD_MEM_IOMEM  IO_ADDRESS(MAXQ_SHD_MEM_IOBASE) //! 1024x32 Address
#define MAXQ_PAGE_MEM_IOMEM IO_ADDRESS(MAXQ_PAGE_MEM_IOBASE)//! 4096x32 Address
#define MAXQ_PROG_MEM_IOMEM IO_ADDRESS(MAXQ_PROG_MEM_IOBASE)//! 4096x32 Address
#define MAXQ_CE_MEM_IOMEM   IO_ADDRESS(MAXQ_CE_MEM_IOBASE)  //! 4096x32 Address
#define MAXQ_UTIL_MEM_IOMEM IO_ADDRESS(MAXQ_UTIL_MEM_IOBASE)//! 4096x32 Address

/** @} */

/** @} */ /* @defgroup IO */

/* -------------------------------------------------------------------------- */
/** @defgroup GPIO_STATUS MAX716XX GPIO Status
 * @{
 */

#define GPIO0_SC1 0x03F00000
#define GPIO1_SC0 0x003F0000

#ifndef STATUS_USES_GPIOS_SC0
#define STATUS_USES_GPIOS_SC0 1
#endif
#if STATUS_USES_GPIOS_SC0 == 1
#define STATUS_GPIO_START       (1<<16)
#define STATUS_GPIO_ERROR       (1<<17)
#define STATUS_GPIO_EXIT        (1<<18)
#define STATUS_GPIO_UNDEFINED   (1<<19)
#define STATUS_GPIO_NMI         (1<<20)
#define STATUS_GPIO_FAULT       (1<<21)
#define STATUS_GPIO_IRQ         (1<<22)
#else /* #if STATUS_USES_GPIOS_SC0 == 1 */
#define STATUS_GPIO_START       (1<<20)
#define STATUS_GPIO_ERROR       (1<<21)
#define STATUS_GPIO_EXIT        (1<<22)
#define STATUS_GPIO_UNDEFINED   (1<<23)
#define STATUS_GPIO_NMI         (1<<24)
#define STATUS_GPIO_FAULT       (1<<25)
#define STATUS_GPIO_IRQ         (1<<26)
#endif /* #if STATUS_USES_GPIOS_SC0 == 1 */

/** @} */

/* -------------------------------------------------------------------------- */
/** @defgroup SYS MAX716XX System Memory
 *
 * Offsets.
 * @{
 */

#define SYSBASE         0xE0000000              //!< Cortex M3 System Base Address
#define SYSBASE_ADDR    IO_ADDRESS(SYSBASE)     //!< Cortex M3 System Base Address

#define NVIC_PORT       0xE000                  //! Interrupt Controller
#define NVIC_IOBASE     (SYSBASE NVIC_PORT)     //! Interrupt Controller
#define NVIC_IOMEM      IO_ADDRESS(NVIC_IOBASE) //! Interrupt Controller

#define INTC_IOBASE     NVIC_IOBASE             //! Interrupt Controller (legacy)
#define INTC_IOMEM      NVIC_IOMEM              //! Interrupt Controller (legacy)

/** @} */

#include "ce.h"         /* CE register addresses */
#include "core_cm3.h"
#include "info_blk.h"
#include "max716xx_gpio_regs.h"
#include "tmr_regs.h"
#include "uart_regs.h"
#include "spi_regs.h"
#include "i2cl_regs.h"
#include "sc_regs.h"
#include "dma_regs.h"
#include "flc_regs.h"
//#include "icache_regs.h"
#include "spi_regs.h"
#include "maxq_com_regs.h"
#include "crypto_regs.h"
#include "trng_regs.h"
//#include "maa_regs.h"
#include "gcr_regs.h"
#include "sir_regs.h"
//#include "crc_regs.h"
#include "test_regs.h"
//#include "trim_regs.h"

#define io_index(__a__, __i__) (__a__ + (__i__ * 0x1000))


/* -------------------------------------------------------------------------- */
/** @defgroup IO structs MAX716XX I/O
 *
 * @{
 */

#define info_blk    ((info_blk_t*)INFO_BLK_BASE)
#define gpio(_i_)   ((gpio_regs_t*)io_index(GPIO0_IOMEM,_i_))
#define tmr(_i_)    ((tmr_regs_t*)io_index(TMR0_IOMEM,_i_))
#define uart(_i_)   ((uart_regs_t*)io_index(UART0_IOMEM,_i_))
#define spi(_i_)    ((spi_regs_t*)io_index(SPI0_IOMEM,_i_))
#define i2c         ((i2c_regs_t*)I2C_IOMEM)
#define sc          ((sc_regs_t*)SC_IOMEM)
#define dma         ((dma_regs_t*)DMA_IOMEM)
#define flc         ((flc_regs_t*)FLC_IOMEM)
#define spis        ((spi_regs_t*)SPIS_IOMEM)
#define maxq_com    ((maxq_com_regs_t*)MAXQ_COM_IOMEM)
#define crypto      ((crypto_regs_t*)CRYPTO_IOMEM)
#define trng        ((trng_regs_t*)TRNG_IOMEM)
#define maa         ((maa_regs_t*)MAA_IOMEM)
#define gcr         ((gcr_regs_t*)GCR_IOMEM)
#define sir         ((sir_regs_t*)SIR_IOMEM)
#define test_regs   ((test_regs_t*)TEST_IOMEM)

/** @} */

/* -------------------------------------------------------------------------- */
/** @defgroup INT_SRC MAX716XX Interruption Sources
 *
 * @{
 */

/*
 * Interrupt Channel Numbers
 */

#define INTNUM_GPIO0    0
#define INTNUM_GPIO1    1
#define INTNUM_TMR0     2
#define INTNUM_TMR1     3
#define INTNUM_TMR2     4
#define INTNUM_TMR3     5
#define INTNUM_TMR4     6
#define INTNUM_TMR5     7
#define INTNUM_TMR6     8
#define INTNUM_UART0    9
#define INTNUM_UART1    10
#define INTNUM_UART2    11
#define INTNUM_UART3    12
#define INTNUM_UART4    13
#define INTNUM_UART5    14
#define INTNUM_SPI0     15
#define INTNUM_SPI1     16
#define INTNUM_I2C      17
#define INTNUM_SC       18
#define INTNUM_WDT      19
#define INTNUM_FLC      20
#define INTNUM_MAXQ_COM 21
#define INTNUM_CRYPTO   22
#define INTNUM_TRNG     23
#define INTNUM_SPIS     24
#define INTNUM_RPU      25

#define INTNUM_DMA0     26
#define INTNUM_DMA1     27
#define INTNUM_DMA2     28
#define INTNUM_DMA3     29
#define INTNUM_DMA4     30
#define INTNUM_DMA5     31
#define INTNUM_DMA6     32
#define INTNUM_DMA7     33
#define INTNUM_DMA8     34
#define INTNUM_DMA9     35
#define INTNUM_DMA10    36
#define INTNUM_DMA11    37
#define INTNUM_DMA12    38
#define INTNUM_DMA13    39
#define INTNUM_DMA14    40
#define INTNUM_DMA15    41

/*DMA interrupt number with idex to select one of the channel */
#define INTNUM_DMA(x)   (INTNUM_DMA0 + (x))

/** @} */ /* @defgroup INT_SRC */

/** @} */ /* @defgroup MAX716XX */

#endif /* MAX716XX_H */

