/*
 * max716xx_gpio_regs.h --
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2012, Maxim Integrated Products
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MAXIM INTEGRATED PRODUCTS ''AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* [INTERNAL] ------------------------------------------------------------------
 * Created on: June 5, 2012
 * Author: Jeremy Brodt
 *
 * ---- Subversion keywords (need to set the keyword property)
 * $Revision: 24 $:  Revision of last commit
 * $Author: ray.vandewalker $:  Author of last commit
 * $Date: 2013-06-07 16:55:51 -0700 (Fri, 07 Jun 2013) $:  Date of last commit
 * [/INTERNAL] -------------------------------------------------------------- */

#ifndef MAX716XX_GPIO_REGS_H_
#define MAX716XX_GPIO_REGS_H_

/** @file max716xx_gpio_regs.h GPIO Registers Header */

/** @defgroup GPIO GPIO Driver
 * @ingroup DRIVER
 *
 * @{
 */

/** @defgroup GPIO_REGS GPIO Registers
 *
 * @note GPIO IP or Specification version number
 *
 * @ingroup GPIO
 * @{
 */

/** @defgroup GPIO_REGS_GPIO0ER0	GPIO Function Enable Register (GPIO0ER0)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n Function Enable
 *
 * @{
 */

#define GPIO0ER0_OFST		0x0			//!< Register offset
#define GPIO0ER0_DFLT		0xFFFFFFFF 	//!< Register default value

/* Bits Fields */

#define GPIO0ER0_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0ER0_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask


/** @} */ /* defgroup GPIO_REGS_GPIO0ER0 */

/** @defgroup GPIO_REGS_GPIO0DIR	GPIO Output Enable Register (GPIO0DIR)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n Direction *
 * @{
 */

#define GPIO0DIR_OFST		0xC	//!< Register offset
#define GPIO0DIR_DFLT		0x0 //!< Register default value

/* Bits Fields */

#define GPIO0DIR_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0DIR_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0DIR */

/** @defgroup GPIO_REGS_GPIO0DRO	GPIO Output Register (GPIO0DRO)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n Output Data Register
 *
 * @{
 */

#define GPIO0DRO_OFST		0x18	//!< Register offset
#define GPIO0DRO_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0DRO_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0DRO_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0DRO */

/** @defgroup GPIO_REGS_GPIO0_OUT_SET	GPIO Output Set Register (GPIO0SET)
 *
 * @li GPIO [n]	-	W: GPIO0.n Set
 *
 * @{
 */

#define GPIO0SET_OFST		0x1C	//!< Register offset
#define GPIO0SET_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0SET_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0SET_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0_OUT_SET */


/** @defgroup GPIO_REGS_GPIO0CLR	GPIO Output Clear Register (GPIO0CLR)
 *
 * @li GPIO [n]	-	W: GPIO0.n
 *
 * @{
 */

#define GPIO0CLR_OFST		0x20	//!< Register offset
#define GPIO0CLR_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0CLR_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0CLR_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0CLR */


/** @defgroup GPIO_REGS_GPIO0DRI	GPIO Input Data Register (GPIO0DRI)
 *
 * @li GPIO [n]	-	R: GPIO0.n
 *
 * @{
 */

#define GPIO0DRI_OFST		0x24	//!< Register offset
#define GPIO0DRI_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0DRI_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0DRI_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0DRI */


/** @defgroup GPIO_REGS_GPIO0IMR0	GPIO Interrupt Mode Register 0 (GPIO0IMR0)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n
 *
 * @{
 */

#define GPIO0IMR0_OFST		0x28	//!< Register offset
#define GPIO0IMR0_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0IMR0_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0IMR0_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0IMR0 */


/** @defgroup GPIO_REGS_GPIO0IMR1	GPIO Interrupt Mode Register 1 (GPIO0IMR1)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n
 *
 * @{
 */

#define GPIO0IMR1_OFST		0x2C	//!< Register offset
#define GPIO0IMR1_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0IMR1_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0IMR1_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0IMR1 */


/** @defgroup GPIO_REGS_GPIO0IER	GPIO Interrupt Enable Register (GPIO0IER)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n
 *
 * @{
 */

#define GPIO0IER_OFST		0x34	//!< Register offset
#define GPIO0IER_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0IER_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0IER_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0IER */


/** @defgroup GPIO_REGS_GPIO0IESET	GPIO Interrupt Enable Set Register (GPIO0IESET)
 *
 * @li GPIO [n]	-	W: GPIO0.n
 *
 * @{
 */

#define GPIO0IESET_OFST		0x38	//!< Register offset
#define GPIO0IESET_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0IESET_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0IESET_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0IESET */


/** @defgroup GPIO_REGS_GPIO0IECLR		GPIO Interrupt Enable Clear Register (GPIO0IECLR)
 *
 * @li GPIO [n]	-	W: GPIO0.n
 *
 * @{
 */

#define GPIO0IECLR_OFST		0x3C	//!< Register offset
#define GPIO0IECLR_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0IECLR_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0IECLR_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0IECLR */


/** @defgroup GPIO_REGS_GPIO0ISR	GPIO Interrupt Status Register (GPIO0ISR)
 *
 * @li GPIO [n]	-	R: GPIO0.n
 *
 * @{
 */

#define GPIO0ISR_OFST		0x40	//!< Register offset
#define GPIO0ISR_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0ISR_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0ISR_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0ISR */


/** @defgroup GPIO_REGS_GPIO0ISCLR	GPIO Interrupt Status Clear Register (GPIO0ISCLR)
 *
 * @li GPIO [n]	-	W: GPIO0.n
 *
 * @{
 */

#define GPIO0ISCLR_OFST		0x48	//!< Register offset
#define GPIO0ISCLR_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0ISCLR_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0ISCLR_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0ISCLR */


/** @defgroup GPIO_REGS_GPIO0PMER	GPIO Power Management Enable Register (GPIO0PMER)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n
 *
 * @{
 */

#define GPIO0PMER_OFST		0x4C	//!< Register offset
#define GPIO0PMER_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0PMER_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0PMER_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0PMER */


/** @defgroup GPIO_REGS_GPIO0MR	GPIO Open Drain Register (GPIO0MR)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n
 *
 * @{
 */

#define GPIO0MR_OFST		0x58	//!< Register offset
#define GPIO0MR_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0MR_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0MR_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0MR */


/** @defgroup GPIO_REGS_GPIO0IMR2	GPIO Interrupt Dual Edge Mode Register (GPIO0IMR2)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n
 *
 * @{
 */

#define GPIO0IMR2_OFST		0x5C	//!< Register offset
#define GPIO0IMR2_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0IMR2_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0IMR2_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0IMR2 */


/** @defgroup GPIO_REGS_GPIO0PUER	GPIO Pull Up Enable Register (GPIO0PUER)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n
 *
 * @{
 */

#define GPIO0PUER_OFST		0x60	//!< Register offset
#define GPIO0PUER_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0PUER_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0PUER_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0PUER */


/** @defgroup GPIO_REGS_GPIO0PDER	GPIO Pull Down Enable Register (GPIO0PDER)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n
 *
 * @{
 */

#define GPIO0PDER_OFST		0x60	//!< Register offset
#define GPIO0PDER_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0PDER_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0PDER_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0PDER */


/** @defgroup GPIO_REGS_GPIO0ER1	GPIO Alternate Function Enable Register (GPIO0ER1)
 *
 * @li GPIO [n]	-	R/W: GPIO0.n
 *
 * @{
 */

#define GPIO0ER1_OFST		0x60	//!< Register offset
#define GPIO0ER1_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO0ER1_BIT_OFST(n)	(n)		//!<GPIO0.n offset

#define GPIO0ER1_BIT_MASK(n)	(1 << n)//!<GPIO0.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO0ER1 */

/** @defgroup GPIO_REGS_GPIO1ER0	GPIO Function Enable Register (GPIO1ER0)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n Function Enable
 *
 * @{
 */

#define GPIO1ER0_OFST		0x0			//!< Register offset
#define GPIO1ER0_DFLT		0xFFFFFFFF 	//!< Register default value

/* Bits Fields */

#define GPIO1ER0_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1ER0_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask


/** @} */ /* defgroup GPIO_REGS_GPIO1ER0 */

/** @defgroup GPIO_REGS_GPIO1DIR	GPIO Output Enable Register (GPIO1DIR)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n Direction
 * @{
 */

#define GPIO1DIR_OFST		0xC	//!< Register offset
#define GPIO1DIR_DFLT		0x0 //!< Register default value

/* Bits Fields */

#define GPIO1DIR_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1DIR_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1DIR */

/** @defgroup GPIO_REGS_GPIO1DRO	GPIO Output Register (GPIO1DRO)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n Output Data Register
 *
 * @{
 */

#define GPIO1DRO_OFST		0x18	//!< Register offset
#define GPIO1DRO_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1DRO_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1DRO_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1DRO */

/** @defgroup GPIO_REGS_GPIO1_OUT_SET	GPIO Output Set Register (GPIO1SET)
 *
 * @li GPIO [n]	-	W: GPIO1.n Set
 *
 * @{
 */

#define GPIO1SET_OFST		0x1C	//!< Register offset
#define GPIO1SET_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1SET_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1SET_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1_OUT_SET */


/** @defgroup GPIO_REGS_GPIO1CLR	GPIO Output Clear Register (GPIO1CLR)
 *
 * @li GPIO [n]	-	W: GPIO1.n
 *
 * @{
 */

#define GPIO1CLR_OFST		0x20	//!< Register offset
#define GPIO1CLR_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1CLR_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1CLR_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1CLR */


/** @defgroup GPIO_REGS_GPIO1DRI	GPIO Input Data Register (GPIO1DRI)
 *
 * @li GPIO [n]	-	R: GPIO1.n
 *
 * @{
 */

#define GPIO1DRI_OFST		0x24	//!< Register offset
#define GPIO1DRI_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1DRI_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1DRI_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1DRI */


/** @defgroup GPIO_REGS_GPIO1IMR0	GPIO Interrupt Mode Register 0 (GPIO1IMR0)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n
 *
 * @{
 */

#define GPIO1IMR0_OFST		0x28	//!< Register offset
#define GPIO1IMR0_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1IMR0_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1IMR0_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1IMR0 */


/** @defgroup GPIO_REGS_GPIO1IMR1	GPIO Interrupt Mode Register 1 (GPIO1IMR1)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n
 *
 * @{
 */

#define GPIO1IMR1_OFST		0x2C	//!< Register offset
#define GPIO1IMR1_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1IMR1_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1IMR1_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1IMR1 */


/** @defgroup GPIO_REGS_GPIO1IER	GPIO Interrupt Enable Register (GPIO1IER)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n
 *
 * @{
 */

#define GPIO1IER_OFST		0x34	//!< Register offset
#define GPIO1IER_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1IER_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1IER_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1IER */


/** @defgroup GPIO_REGS_GPIO1IESET	GPIO Interrupt Enable Set Register (GPIO1IESET)
 *
 * @li GPIO [n]	-	W: GPIO1.n
 *
 * @{
 */

#define GPIO1IESET_OFST		0x38	//!< Register offset
#define GPIO1IESET_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1IESET_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1IESET_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1IESET */


/** @defgroup GPIO_REGS_GPIO1IECLR		GPIO Interrupt Enable Clear Register (GPIO1IECLR)
 *
 * @li GPIO [n]	-	W: GPIO1.n
 *
 * @{
 */

#define GPIO1IECLR_OFST		0x3C	//!< Register offset
#define GPIO1IECLR_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1IECLR_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1IECLR_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1IECLR */


/** @defgroup GPIO_REGS_GPIO1ISR	GPIO Interrupt Status Register (GPIO1ISR)
 *
 * @li GPIO [n]	-	R: GPIO1.n
 *
 * @{
 */

#define GPIO1ISR_OFST		0x40	//!< Register offset
#define GPIO1ISR_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1ISR_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1ISR_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1ISR */


/** @defgroup GPIO_REGS_GPIO1ISCLR	GPIO Interrupt Status Clear Register (GPIO1ISCLR)
 *
 * @li GPIO [n]	-	W: GPIO1.n
 *
 * @{
 */

#define GPIO1ISCLR_OFST		0x48	//!< Register offset
#define GPIO1ISCLR_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1ISCLR_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1ISCLR_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1ISCLR */


/** @defgroup GPIO_REGS_GPIO1PMER	GPIO Power Management Enable Register (GPIO1PMER)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n
 *
 * @{
 */

#define GPIO1PMER_OFST		0x4C	//!< Register offset
#define GPIO1PMER_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1PMER_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1PMER_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1PMER */


/** @defgroup GPIO_REGS_GPIO1MR	GPIO Open Drain Register (GPIO1MR)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n
 *
 * @{
 */

#define GPIO1MR_OFST		0x58	//!< Register offset
#define GPIO1MR_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1MR_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1MR_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1MR */


/** @defgroup GPIO_REGS_GPIO1IMR2	GPIO Interrupt Dual Edge Mode Register (GPIO1IMR2)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n
 *
 * @{
 */

#define GPIO1IMR2_OFST		0x5C	//!< Register offset
#define GPIO1IMR2_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1IMR2_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1IMR2_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1IMR2 */


/** @defgroup GPIO_REGS_GPIO1PUER	GPIO Pull Up Enable Register (GPIO1PUER)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n
 *
 * @{
 */

#define GPIO1PUER_OFST		0x60	//!< Register offset
#define GPIO1PUER_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1PUER_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1PUER_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1PUER */


/** @defgroup GPIO_REGS_GPIO1PDER	GPIO Pull Down Enable Register (GPIO1PDER)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n
 *
 * @{
 */

#define GPIO1PDER_OFST		0x60	//!< Register offset
#define GPIO1PDER_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1PDER_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1PDER_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1PDER */


/** @defgroup GPIO_REGS_GPIO1ER1	GPIO Alternate Function Enable Register (GPIO1ER1)
 *
 * @li GPIO [n]	-	R/W: GPIO1.n
 *
 * @{
 */

#define GPIO1ER1_OFST		0x60	//!< Register offset
#define GPIO1ER1_DFLT		0x0 	//!< Register default value

/* Bits Fields */

#define GPIO1ER1_BIT_OFST(n)	(n)		//!<GPIO1.n offset

#define GPIO1ER1_BIT_MASK(n)	(1 << n)//!<GPIO1.n mask

/** @} */ /* defgroup GPIO_REGS_GPIO1ER1 */

#ifndef __ASSEMBLER__
/* -------------------------------------------------------------------------- */
/** GPIO Registers.
 *
 */
typedef volatile struct gpio_regs_{
	unsigned int en;
	/**/
	unsigned int en_set;
	unsigned int en_clr;
	/**/
	unsigned int out_en;
	/**/
	unsigned int out_en_set;
	unsigned int out_en_clr;
	/**/
	unsigned int out;
	unsigned int out_set;
	unsigned int out_clr;
	unsigned int in;
	unsigned int int_mod;
	unsigned int int_pol;
	/**/
	unsigned int rfu5;
	/**/
	unsigned int int_en;
	unsigned int int_en_set;
	unsigned int int_en_clr;
	unsigned int int_stat;
	/**/
	unsigned int rfu6;
	/**/
	unsigned int int_clr;
	unsigned int wake_en;
	/**/
	unsigned int rfu7;
	unsigned int rfu8;
	/**/
	unsigned int open_drain_en;
	unsigned int int_dual_edge;
	unsigned int pad_cfg1;
	unsigned int pad_cfg2;
	unsigned int en1;
	unsigned int en1_set;
	unsigned int en1_clr;
} gpio_regs_t;

#endif /* __ASSEMBLER__ */

/** @} */ /* @defgroup GPIO_REGS */

/** @} */ /* @defgroup GPIO */

#endif /* MAX716XX_GPIO_REGS_H_ */
