/*
 * nvic_regs.h --
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2012, Maxim Integrated Products
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MAXIM INTEGRATED PRODUCTS ''AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* [INTERNAL] ------------------------------------------------------------------
 * Created on: June 6, 2012
 * Author: Jeremy Brodt
 *
 * ---- Subversion keywords (need to set the keyword property)
 * $Revision: 21 $:  Revision of last commit
 * $Author: ray.vandewalker $:  Author of last commit
 * $Date: 2013-06-07 16:34:10 -0700 (Fri, 07 Jun 2013) $:  Date of last commit
 * [/INTERNAL] -------------------------------------------------------------- */

#ifndef NVIC_REGS_H_
#define NVIC_REGS_H_

#define NVIC_BASE				0xE000E000

#define NVIC_ICTR_OFST			0x004

#define NVIC_ISER0_OFST			0x100
#define NVIC_ISER1_OFST			0x104
#define NVIC_ISER2_OFST			0x108
#define NVIC_ISER3_OFST			0x10C
#define NVIC_ISER4_OFST			0x110
#define NVIC_ISER5_OFST			0x114
#define NVIC_ISER6_OFST			0x118
#define NVIC_ISER7_OFST			0x11C

#define NVIC_ICER0_OFST			0x180
#define NVIC_ICER1_OFST			0x184
#define NVIC_ICER2_OFST			0x188
#define NVIC_ICER3_OFST			0x18C
#define NVIC_ICER4_OFST			0x190
#define NVIC_ICER5_OFST			0x194
#define NVIC_ICER6_OFST			0x198
#define NVIC_ICER7_OFST			0x19C

#define NVIC_ISPR0_OFST			0x200
#define NVIC_ISPR1_OFST			0x204
#define NVIC_ISPR2_OFST			0x208
#define NVIC_ISPR3_OFST			0x20C
#define NVIC_ISPR4_OFST			0x210
#define NVIC_ISPR5_OFST			0x214
#define NVIC_ISPR6_OFST			0x218
#define NVIC_ISPR7_OFST			0x21C

#define NVIC_ICPR0_OFST			0x280
#define NVIC_ICPR1_OFST			0x284
#define NVIC_ICPR2_OFST			0x288
#define NVIC_ICPR3_OFST			0x28C
#define NVIC_ICPR4_OFST			0x290
#define NVIC_ICPR5_OFST			0x294
#define NVIC_ICPR6_OFST			0x298
#define NVIC_ICPR7_OFST			0x29C

#define NVIC_IABR0_OFST			0x300
#define NVIC_IABR1_OFST			0x304
#define NVIC_IABR2_OFST			0x308
#define NVIC_IABR3_OFST			0x30C
#define NVIC_IABR4_OFST			0x310
#define NVIC_IABR5_OFST			0x314
#define NVIC_IABR6_OFST			0x318
#define NVIC_IABR7_OFST			0x31C

#define NVIC_VTOR_OFST			0xD08

#ifndef __ASSEMBLER__
/* -------------------------------------------------------------------------- */

/** INTC Registers.
 */
typedef volatile struct _nvic_regs_{
	unsigned int space00;					// +0x000
	unsigned int ictr;						// +0x004
	unsigned char space01[0x100 - 0x008];	// +0x008
	unsigned int enable_set[8];				// +0x100
	unsigned char space02[0x180 - 0x120];	// +0x120
	unsigned int enable_clr[8];				// +0x180
	unsigned char space03[0x200 - 0x1A0];	// +0x1A0
	unsigned int pend_set[8];				// +0x200
	unsigned char space04[0x280 - 0x220];	// +0x220
	unsigned int pend_clr[8];				// +0x280
	unsigned char space05[0x300 - 0x2A0];	// +0x2A0
	unsigned int active[8];					// +0x300
	unsigned char space06[0x400 - 0x320];	// +0x320
	unsigned char priority[256];			// +0x400
	unsigned char space07[0xD08 - 0x500];	// +0x500
	unsigned int vtor;						// +0xD08
} nvic_regs_t;

/** Interruption Priorities
 */
typedef unsigned char nvic_prio_t;

#endif /* __ASSEMBLER__ */

#endif /* NVIC_REGS_H_ */

