/*
 * sc_regs.h --
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2012, Maxim Integrated Products
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MAXIM INTEGRATED PRODUCTS ''AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* [INTERNAL] ------------------------------------------------------------------
 * Created on: June 5, 2012
 * Author: Jeremy Brodt
 *
 * ---- Subversion keywords (need to set the keyword property)
 * $Revision: 21 $:  Revision of last commit
 * $Author: ray.vandewalker $:  Author of last commit
 * $Date: 2013-06-07 16:34:10 -0700 (Fri, 07 Jun 2013) $:  Date of last commit
 * [/INTERNAL] -------------------------------------------------------------- */

#ifndef _SC_REGS_H_
#define _SC_REGS_H_

/** @file sc_regs.h SC Registers Header */

/** @defgroup SC SC Driver */

/** @defgroup SC_REGS SC Registers
 *
 * @note SC IP or Specification version number
 *
 * @ingroup SC
 * @{
 */

/** @defgroup SC_REGS_CR SC Control Register Register
 *
 * @li SCxCR [0] - R/W: CONV
 * @li SCxCR [1] - R/W: CREP
 * @li SCxCR [2] - R/W: WTEN
 * @li SCxCR [3] - R/W: UART
 * @li SCxCR [4] - R/W: CCEN
 * @li SCxCR [5] - R/W: RXFLUSH
 * @li SCxCR [6] - R/W: TXFLUSH
 * @li SCxCR [7] - R: RFU
 * @li SCxCR [11:8] - R/W: RXTHD
 * @li SCxCR [15:12] - R/W: TXTHD
 * @li SCxCR [31:16] - R: RFU
 *
 * @{
 */
#define SC_CR_OFST					0x0	//!< Control Register offset
#define SC_CR_DFLT					0x00000000	//!< Control Register default value
/* Bits Fields */
#define SC_CR_CONV_OFST				0	//!< CONV offset
#define SC_CR_CONV_MASK_NO_OFST		0x1	//!< CONV mask
#define SC_CR_CONV_MASK				(SC_CR_CONV_MASK_NO_OFST << SC_CR_CONV_OFST)

#define SC_CR_CREP_OFST				1 //!< CREP offset
#define SC_CR_CREP_MASK_NO_OFST		0x1 //!< CREP mask
#define SC_CR_CREP_MASK				(SC_CR_CREP_MASK_NO_OFST << SC_CR_CREP_OFST)

#define SC_CR_WTEN_OFST				2 //!< WTEN offset
#define SC_CR_WTEN_MASK_NO_OFST		0x1 //!< WTEN mask
#define SC_CR_WTEN_MASK				(SC_CR_WTEN_MASK_NO_OFST << SC_CR_WTEN_OFST)

#define SC_CR_UART_OFST				3 //!< UART offset
#define SC_CR_UART_MASK_NO_OFST		0x1 //!< UART mask
#define SC_CR_UART_MASK				(SC_CR_UART_MASK_NO_OFST << SC_CR_UART_OFST)

#define SC_CR_CCEN_OFST				4 //!< CCEN offset
#define SC_CR_CCEN_MASK_NO_OFST		0x1 //!< CCEN mask
#define SC_CR_CCEN_MASK				(SC_CR_CCEN_MASK_NO_OFST << SC_CR_CCEN_OFST)

#define SC_CR_RXFLUSH_OFST			5 //!< RXFLUSH offset
#define SC_CR_RXFLUSH_MASK_NO_OFST	0x1 //!< RXFLUSH mask
#define SC_CR_RXFLUSH_MASK			(SC_CR_RXFLUSH_MASK_NO_OFST << SC_CR_RXFLUSH_OFST)

#define SC_CR_TXFLUSH_OFST			6 //!< TXFLUSH offset
#define SC_CR_TXFLUSH_MASK_NO_OFST	0x1 //!< TXFLUSH mask
#define SC_CR_TXFLUSH_MASK			(SC_CR_TXFLUSH_MASK_NO_OFST << SC_CR_TXFLUSH_OFST)

#define SC_CR_RXTHD_OFST				8 //!< RXTHD offset
#define SC_CR_RXTHD_MASK_NO_OFST		0x4 //!< RXTHD mask
#define SC_CR_RXTHD_MASK				(SC_CR_RXTHD_MASK_NO_OFST << SC_CR_RXTHD_OFST)

#define SC_CR_TXTHD_OFST				12 //!< TXTHD offset
#define SC_CR_TXTHD_MASK_NO_OFST		0x4 //!< TXTHD mask
#define SC_CR_TXTHD_MASK				(SC_CR_TXTHD_MASK_NO_OFST << SC_CR_TXTHD_OFST)
/** @} */ /* @defgroup SC_REGS_CR */

/** @defgroup SC_REGS_SR SC Status Register
 *
 * @li SCxSR [0] - R/C: PAR
 * @li SCxSR [1] - R: WTOV
 * @li SCxSR [2] - R: CCOV
 * @li SCxSR [3] - R/C: TXCF
 * @li SCxSR [4] - R: RXEMPTY
 * @li SCxSR [5] - R: RXFULL
 * @li SCxSR [6] - R: TXEMPTY
 * @li SCxSR [7] - R: TXFULL
 * @li SCxSR [11:8] - R: RXELT
 * @li SCxSR [15:12] - R: TXELT
 * @li SCxSR [31:16] - R: RFU
 *
 * @{
 */
#define SC_SR_OFST					0x4	//!< Status Register offset
#define SC_SR_DFLT					0x00000050	//!< Status Register default value
/* Bits Fields */
#define SC_SR_PAR_OFST				0	//!< PAR offset
#define SC_SR_PAR_MASK_NO_OFST		0x1	//!< PAR mask
#define SC_SR_PAR_MASK				(SC_SR_PAR_MASK_NO_OFST << SC_SR_PAR_OFST)

#define SC_SR_WTOV_OFST				1 //!< WTOV offset
#define SC_SR_WTOV_MASK_NO_OFST		0x1 //!< WTOV mask
#define SC_SR_WTOV_MASK				(SC_SR_WTOV_MASK_NO_OFST << SC_SR_WTOV_OFST)

#define SC_SR_CCOV_OFST				2 //!< CCOV offset
#define SC_SR_CCOV_MASK_NO_OFST		0x1 //!< CCOV mask
#define SC_SR_CCOV_MASK				(SC_SR_CCOV_MASK_NO_OFST << SC_SR_CCOV_OFST)

#define SC_SR_TXCF_OFST				3 //!< TXCF offset
#define SC_SR_TXCF_MASK_NO_OFST		0x1 //!< TXCF mask
#define SC_SR_TXCF_MASK				(SC_SR_TXCF_MASK_NO_OFST << SC_SR_TXCF_OFST)

#define SC_SR_RXEMPTY_OFST			4 //!< RXEMPTY offset
#define SC_SR_RXEMPTY_MASK_NO_OFST	0x1 //!< RXEMPTY mask
#define SC_SR_RXEMPTY_MASK			(SC_SR_RXEMPTY_MASK_NO_OFST << SC_SR_RXEMPTY_OFST)

#define SC_SR_RXFULL_OFST				5 //!< RXFULL offset
#define SC_SR_RXFULL_MASK_NO_OFST		0x1 //!< RXFULL mask
#define SC_SR_RXFULL_MASK				(SC_SR_RXFULL_MASK_NO_OFST << SC_SR_RXFULL_OFST)

#define SC_SR_TXEMPTY_OFST			6 //!< TXEMPTY offset
#define SC_SR_TXEMPTY_MASK_NO_OFST	0x1 //!< TXEMPTY mask
#define SC_SR_TXEMPTY_MASK			(SC_SR_TXEMPTY_MASK_NO_OFST << SC_SR_TXEMPTY_OFST)

#define SC_SR_TXFULL_OFST				7 //!< TXFULL offset
#define SC_SR_TXFULL_MASK_NO_OFST		0x1 //!< TXFULL mask
#define SC_SR_TXFULL_MASK				(SC_SR_TXFULL_MASK_NO_OFST << SC_SR_TXFULL_OFST)

#define SC_SR_RXELT_OFST				8 //!< RXELT offset
#define SC_SR_RXELT_MASK_NO_OFST		0x4 //!< RXELT mask
#define SC_SR_RXELT_MASK				(SC_SR_RXELT_MASK_NO_OFST << SC_SR_RXELT_OFST)

#define SC_SR_TXELT_OFST				12 //!< TXELT offset
#define SC_SR_TXELT_MASK_NO_OFST		0x4 //!< TXELT mask
#define SC_SR_TXELT_MASK				(SC_SR_TXELT_MASK_NO_OFST << SC_SR_TXELT_OFST)
/** @} */ /* @defgroup SC_REGS_SR */

/** @defgroup SC_REGS_PNR SC Pin Register
 *
 * @li SCxPNR [0] - R/W: CRDRST
 * @li SCxPNR [1] - R/W: CRDCLK
 * @li SCxPNR [2] - R/W: CRDIO
 * @li SCxPNR [3] - R/W: CRDC4
 * @li SCxPNR [4] - R/W: CRDC8
 * @li SCxPNR [5] - R/W: CLKSEL
 * @li SCxPNR [31:6] - R: RFU
 *
 * @{
 */
#define SC_PNR_OFST					0x8	//!< Pin Register offset
#define SC_PNR_DFLT					0x00000000	//!< Pin Register default value
/* Bits Fields */
#define SC_PNR_CRDRST_OFST			0	//!< CRDRST offset
#define SC_PNR_CRDRST_MASK_NO_OFST	0x1	//!< CRDRST mask
#define SC_PNR_CRDRST_MASK			(SC_PNR_CRDRST_MASK_NO_OFST << SC_PNR_CRDRST_OFST)

#define SC_PNR_CRDCLK_OFST			1 //!< CRDCLK offset
#define SC_PNR_CRDCLK_MASK_NO_OFST	0x1 //!< CRDCLK mask
#define SC_PNR_CRDCLK_MASK			(SC_PNR_CRDCLK_MASK_NO_OFST << SC_PNR_CRDCLK_OFST)

#define SC_PNR_CRDIO_OFST				2 //!< CRDIO offset
#define SC_PNR_CRDIO_MASK_NO_OFST		0x1 //!< CRDIO mask
#define SC_PNR_CRDIO_MASK				(SC_PNR_CRDIO_MASK_NO_OFST << SC_PNR_CRDIO_OFST)

#define SC_PNR_CRDC4_OFST				4 //!< CRDC4 offset
#define SC_PNR_CRDC4_MASK_NO_OFST		0x1 //!< CRDC4 mask
#define SC_PNR_CRDC4_MASK				(SC_PNR_CRDC4_MASK_NO_OFST << SC_PNR_CRDC4_OFST)

#define SC_PNR_CRDC8_OFST				5 //!< CRDC8 offset
#define SC_PNR_CRDC8_MASK_NO_OFST		0x1 //!< CRDC8 mask
#define SC_PNR_CRDC8_MASK				(SC_PNR_CRDC8_MASK_NO_OFST << SC_PNR_CRDC8_OFST)

#define SC_PNR_CLKSEL_OFST			6 //!< CLKSEL offset
#define SC_PNR_CLKSEL_MASK_NO_OFST	0x1 //!< CLKSEL mask
#define SC_PNR_CLKSEL_MASK			(SC_PNR_CLKSEL_MASK_NO_OFST << SC_PNR_CLKSEL_OFST)
/** @} */ /* @defgroup SC_REGS_PNR */

/** @defgroup SC_REGS_ETUR SC ETU Register
 *
 * @li SCxETUR [14:0] - R/W: ETU
 * @li SCxETUR [15] - R/W: COMP
 * @li SCxETUR [16] - R/W: HALF
 * @li SCxETUR [31:17] - R: RFU
 *
 * @{
 */
#define SC_ETUR_OFST					0xc	//!< ETU Register offset
#define SC_ETUR_DFLT					0x00000000	//!< ETU Register default value
/* Bits Fields */
#define SC_ETUR_ETU_OFST				0	//!< ETU offset
#define SC_ETUR_ETU_MASK_NO_OFST		0x7fff	//!< ETU mask
#define SC_ETUR_ETU_MASK				(SC_ETUR_ETU_MASK_NO_OFST << SC_ETUR_ETU_OFST)

#define SC_ETUR_COMP_OFST				15 //!< COMP offset
#define SC_ETUR_COMP_MASK_NO_OFST		0x1 //!< COMP mask
#define SC_ETUR_COMP_MASK				(SC_ETUR_COMP_MASK_NO_OFST << SC_ETUR_COMP_OFST)

#define SC_ETUR_HALF_OFST				16 //!< HALF offset
#define SC_ETUR_HALF_MASK_NO_OFST		0x1 //!< HALF mask
#define SC_ETUR_HALF_MASK				(SC_ETUR_HALF_MASK_NO_OFST << SC_ETUR_HALF_OFST)
/** @} */ /* @defgroup SC_REGS_ETUR */

/** @defgroup SC_REGS_GTR SC Guard Time Register
 *
 * @li SCxGTR [15:0] - R/W: GT
 * @li SCxGTR [31:16] - R: RFU
 *
 * @{
 */
#define SC_GTR_OFST					0x10	//!< GT Register offset
#define SC_GTR_DFLT					0x00000000	//!< GT Register default value
/* Bits Fields */
#define SC_GTR_GT_OFST				0	//!< GT offset
#define SC_GTR_GT_MASK_NO_OFST		0xffff	//!< GT mask
#define SC_GTR_GT_MASK				(SC_GTR_GT_MASK_NO_OFST << SC_GTR_GT_OFST)
/** @} */ /* @defgroup SC_REGS_ETUR */

/** @defgroup SC_REGS_WT0R SC Waiting Time 0 Register
 *
 * @li SCxWT0R [31:0] - R/W: WT
 *
 * @{
 */
#define SC_WT0R_OFST					0x14	//!< WT0 Register offset
#define SC_WT0R_DFLT					0x00000000	//!< WT0 Register default value
/* Bits Fields */
#define SC_WT0R_WT_OFST				0	//!< WT offset
#define SC_WT0R_WT_MASK_NO_OFST		0xffffffff	//!< WT mask
#define SC_WT0R_WT_MASK				(SC_WT0R_WT_MASK_NO_OFST << SC_WT0R_WT_OFST)
/** @} */ /* @defgroup SC_REGS_WT0R */

/** @defgroup SC_REGS_WT0R SC Waiting Time 1 Register
 *
 * @li SCxWT1R [7:0] - R/W: WT
 * @li SCxWT1R [31:8] - R: RFU
 *
 * @{
 */
#define SC_WT1R_OFST					0x18	//!< WT1 Register offset
#define SC_WT1R_DFLT					0x00000000	//!< WT1 Register default value
/* Bits Fields */
#define SC_WT1R_WT_OFST				0	//!< WT offset
#define SC_WT1R_WT_MASK_NO_OFST		0xff	//!< WT mask
#define SC_WT1R_WT_MASK				(SC_WT1R_WT_MASK_NO_OFST << SC_WT1R_WT_OFST)
/** @} */ /* @defgroup SC_REGS_WT1R */

/** @defgroup SC_REGS_IER SC Interrupt Enable Register
 *
 * @li SCxIER [0] - R/W: PARIE
 * @li SCxIER [1] - R/W: WTIE
 * @li SCxIER [2] - R/W: CTIE
 * @li SCxIER [3] - R/W: TCIE
 * @li SCxIER [4] - R/W: RXEIE
 * @li SCxIER [5] - R/W: RXTIE
 * @li SCxIER [6] - R/W: RXFIE
 * @li SCxIER [7] - R/W: TXEIE
 * @li SCxIER [8] - R/W: TXTIE
 * @li SCxIER [31:9] - R: RFU
 *
 * @{
 */
#define SC_IER_OFST					0x1c	//!< Interrupt Enable Register offset
#define SC_IER_DFLT					0x00000000	//!< Interrupt Enable Register default value
/* Bits Fields */
#define SC_IER_PARIE_OFST				0 //!< PARIE offset
#define SC_IER_PARIE_MASK_NO_OFST		0x1 //!< PARIE mask
#define SC_IER_PARIE_MASK				(SC_IER_PARIE_MASK_NO_OFST << SC_IER_PARIE_OFST)

#define SC_IER_WTIE_OFST				1 //!< WTIE offset
#define SC_IER_WTIE_MASK_NO_OFST		0x1 //!< WTIE mask
#define SC_IER_WTIE_MASK				(SC_IER_WTIE_MASK_NO_OFST << SC_IER_WTIE_OFST)

#define SC_IER_CTIE_OFST				2 //!< CTIE offset
#define SC_IER_CTIE_MASK_NO_OFST		0x1 //!< CTIE mask
#define SC_IER_CTIE_MASK				(SC_IER_CTIE_MASK_NO_OFST << SC_IER_CTIE_OFST)

#define SC_ISR_TCIE_OFST				3 //!< TCIE offset
#define SC_ISR_TCIE_MASK_NO_OFST		0x1 //!< TCIE mask
#define SC_ISR_TCIE_MASK				(SC_ISR_TCIE_MASK_NO_OFST << SC_ISR_TCIE_OFST)

#define SC_IER_RXEIE_OFST				4 //!< RXEIE offset
#define SC_IER_RXEIE_MASK_NO_OFST		0x1 //!< RXEIE mask
#define SC_IER_RXEIE_MASK				(SC_IER_RXEIE_MASK_NO_OFST << SC_IER_RXEIE_OFST)

#define SC_IER_RXTIE_OFST				5 //!< RXTIE offset
#define SC_IER_RXTIE_MASK_NO_OFST		0x1 //!< RXTIE mask
#define SC_IER_RXTIE_MASK				(SC_IER_RXTIE_MASK_NO_OFST << SC_IER_RXTIE_OFST)

#define SC_IER_RXFIE_OFST				6 //!< RXFIE offset
#define SC_IER_RXFIE_MASK_NO_OFST		0x1 //!< RXFIE mask
#define SC_IER_RXFIE_MASK				(SC_IER_RXFIE_MASK_NO_OFST << SC_IER_RXFIE_OFST)

#define SC_IER_TXEIE_OFST				7 //!< TXEIE offset
#define SC_IER_TXEIE_MASK_NO_OFST		0x1 //!< TXEIE mask
#define SC_IER_TXEIE_MASK				(SC_IER_TXEIE_MASK_NO_OFST << SC_IER_TXEIE_OFST)

#define SC_IER_TXTIE_OFST				8 //!< TXTIE offset
#define SC_IER_TXTIE_MASK_NO_OFST		0x1 //!< TXTIE mask
#define SC_IER_TXTIE_MASK				(SC_IER_TXTIE_MASK_NO_OFST << SC_IER_TXTIE_OFST)
/** @} */ /* @defgroup SC_REGS_IER */

/** @defgroup SC_REGS_ISR SC Interrupt Status Register
 *
 * @li SCxISR [0] - R/C: PARIE
 * @li SCxISR [1] - R/C: WTIE
 * @li SCxISR [2] - R/C: CTIE
 * @li SCxISR [3] - R/C: TCIS
 * @li SCxISR [4] - R/C: RXEIE
 * @li SCxISR [5] - R/C: RXTIE
 * @li SCxISR [6] - R/C: RXFIE
 * @li SCxISR [7] - R/C: TXEIE
 * @li SCxISR [8] - R/C: TXTIE
 * @li SCxISR [31:9] - R: RFU
 *
 * @{
 */
#define SC_ISR_OFST					0x20	//!< Interrupt Status Register offset
#define SC_ISR_DFLT					0x00000000	//!< Interrupt Status Register default value
/* Bits Fields */
#define SC_ISR_PARIS_OFST				0 //!< PARIS offset
#define SC_ISR_PARIS_MASK_NO_OFST		0x1 //!< PARIS mask
#define SC_ISR_PARIS_MASK				(SC_ISR_PARIS_MASK_NO_OFST << SC_ISR_PARIS_OFST)

#define SC_ISR_WTIS_OFST				1 //!< WTIS offset
#define SC_ISR_WTIS_MASK_NO_OFST		0x1 //!< WTIS mask
#define SC_ISR_WTIS_MASK				(SC_ISR_WTIS_MASK_NO_OFST << SC_ISR_WTIS_OFST)

#define SC_ISR_CTIS_OFST				2 //!< CTIS offset
#define SC_ISR_CTIS_MASK_NO_OFST		0x1 //!< CTIS mask
#define SC_ISR_CTIS_MASK				(SC_ISR_CTIS_MASK_NO_OFST << SC_ISR_CTIS_OFST)

#define SC_ISR_TCIS_OFST				3 //!< TCIS offset
#define SC_ISR_TCIS_MASK_NO_OFST		0x1 //!< TCIS mask
#define SC_ISR_TCIS_MASK				(SC_ISR_TIS_MASK_NO_OFST << SC_ISR_TCIS_OFST)

#define SC_ISR_RXEIS_OFST				4 //!< RXEIS offset
#define SC_ISR_RXEIS_MASK_NO_OFST		0x1 //!< RXEIS mask
#define SC_ISR_RXEIS_MASK				(SC_ISR_RXEIS_MASK_NO_OFST << SC_ISR_RXEIS_OFST)

#define SC_ISR_RXTIS_OFST				5 //!< RXTIS offset
#define SC_ISR_RXTIS_MASK_NO_OFST		0x1 //!< RXTIS mask
#define SC_ISR_RXTIS_MASK				(SC_ISR_RXTIS_MASK_NO_OFST << SC_ISR_RXTIS_OFST)

#define SC_ISR_RXFIS_OFST				6 //!< RXFIS offset
#define SC_ISR_RXFIS_MASK_NO_OFST		0x1 //!< RXFIS mask
#define SC_ISR_RXFIS_MASK				(SC_ISR_RXFIS_MASK_NO_OFST << SC_ISR_RXFIS_OFST)

#define SC_ISR_TXEIS_OFST				7 //!< TXEIS offset
#define SC_ISR_TXEIS_MASK_NO_OFST		0x1 //!< TXEIS mask
#define SC_ISR_TXEIS_MASK				(SC_ISR_TXEIS_MASK_NO_OFST << SC_ISR_TXEIS_OFST)

#define SC_ISR_TXTIS_OFST				8 //!< TXTIS offset
#define SC_ISR_TXTIS_MASK_NO_OFST		0x1 //!< TXTIS mask
#define SC_ISR_TXTIS_MASK				(SC_ISR_TXTIS_MASK_NO_OFST << SC_ISR_TXTIS_OFST)
/** @} */ /* @defgroup SC_REGS_ISR */

/** @defgroup SC_REGS_TXR SC TX Register
 *
 * @li SCxTXR [7:0] - W: DATA
 * @li SCxTXR [31:8] - R: RFU
 *
 * @{
 */
#define SC_TXR_OFST					0x24 //!< TX Register offset
#define SC_TXR_DFLT					0x00000000	//!< TX Register default value
/* Bits Fields */
#define SC_TXR_DATA_OFST				0 //!< DATA offset
#define SC_TXR_DATA_MASK_NO_OFST		0xff //!< DATA mask
#define SC_TXR_DATA_MASK				(SC_TXR_DATA_MASK_NO_OFST << SC_TXR_DATA_OFST)
/** @} */ /* @defgroup SC_REGS_TXR */

/** @defgroup SC_REGS_RXR SC RX Register
 *
 * @li SCxTXR [7:0] - R: DATA
 * @li SCxTXR [8] - R: PARER
 * @li SCxTXR [31:9] - R: RFU
 *
 * @{
 */
#define SC_RXR_OFST					0x28 //!< RX Register offset
#define SC_RXR_DFLT					0x00000000 //!< RX Register default value
/* Bits Fields */
#define SC_RXR_DATA_OFST				0 //!< DATA offset
#define SC_RXR_DATA_MASK_NO_OFST		0xff //!< DATA mask
#define SC_RXR_DATA_MASK				(SC_RXR_DATA_MASK_NO_OFST << SC_RXR_DATA_OFST)

#define SC_TXR_PARER_OFST				8 //!< PARER offset
#define SC_TXR_PARER_MASK_NO_OFST		0x1 //!< PARER mask
#define SC_TXR_PARER_MASK				(SC_RXR_PARER_MASK_NO_OFST << SC_RXR_PARER_OFST)
/** @} */ /* @defgroup SC_REGS_RXR */

/** @defgroup SC_REGS_CCR SC Clock Counter Register
 *
 * @li SCxCCR [23:0] - R/W: CCYC
 * @li SCxCCR [30:24] - R: RFU
 * @li SCxCCR [31] - R/W: MAN
 *
 * @{
 */
#define SC_CCR_OFST					0x2c //!< Clock Counter Register offset
#define SC_CCR_DFLT					0x00000000 //!< Clock Counter Register default value
/* Bits Fields */
#define SC_CCR_CCYC_OFST				0 //!< CCYC offset
#define SC_CCR_CCYC_MASK_NO_OFST		0xffffff //!< CCYC mask
#define SC_CCR_CCYC_MASK				(SC_CCR_CCYC_MASK_NO_OFST << SC_CCR_CCYC_OFST)

#define SC_CCR_MAN_OFST				31 //!< MAN offset
#define SC_CCR_MAN_MASK_NO_OFST		0x1 //!< MAN mask
#define SC_CCR_MAN_MASK				(SC_CCR_MAN_MASK_NO_OFST << SC_CCR_MAN_OFST)
/** @} */ /* @defgroup SC_REGS_CCR */

/* -------------------------------------------------------------------------- */
#ifndef __ASSEMBLER__
/* -------------------------------------------------------------------------- */
/** SC Registers.
 *
 */
typedef volatile struct _sc_regs_
{
	/** SCx */
	volatile unsigned int sc_cr;	//< SC control register
	volatile unsigned int sc_sr;	//< SC status register
	volatile unsigned int sc_pnr;	//< SC pin register
	volatile unsigned int sc_etur;	//< SC etu register
	volatile unsigned int sc_gtr;	//< SC guard time register
	volatile unsigned int sc_wt0r;	//< SC waiting time 0 register
	volatile unsigned int sc_wt1r;	//< SC waiting time 1 register
	volatile unsigned int sc_ier;	//< SC interrupt enable register
	volatile unsigned int sc_isr;	//< SC interrupt status register
	volatile unsigned int sc_txr;	//< SC tx register
	volatile unsigned int sc_rxr;	//< SC rx register
	volatile unsigned int sc_ccr;	//< SC clock counter register

} sc_regs_t;

#endif /* __ASSEMBLER__ */

/** @} */ /* @defgroup SC_REGS */

#endif /* _SC_REGS_H_ */
