/*
 * spi_regs.h --
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2012, Maxim Integrated Products
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MAXIM INTEGRATED PRODUCTS ''AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* [INTERNAL] ------------------------------------------------------------------
 * Created on: June 5, 2012
 * Author: Jeremy Brodt
 *
 * ---- Subversion keywords (need to set the keyword property)
 * $Revision: 21 $:  Revision of last commit
 * $Author: ray.vandewalker $:  Author of last commit
 * $Date: 2013-06-07 16:34:10 -0700 (Fri, 07 Jun 2013) $:  Date of last commit
 * [/INTERNAL] -------------------------------------------------------------- */

#ifndef SPI_REGS_H_
#define SPI_REGS_H_

/** @file spi_regs.h SPI Registers Header */

/** @defgroup SPI SPI Driver
 * @ingroup DRIVER
 */

/** @defgroup SPI_REGS SPI Registers
 *
 * @note SPI IP or Specification version number
 *
 * @ingroup SPI
 * @{
 */
/** @defgroup SPI_REGS_DR Data Register (DR)
 *
 * @li DATA [15:0]	- R/W: data
 * @li RFU [31:16]	- R: reserved
 * @{
 */
#define SPI_DATA_OFST	0x00000000	//!< Register offset
#define SPI_DATA_DFLT	0x00000000	//!< Register default value

/* Bits Fields */

#define SPI_DATA_DATA_OFST	0	//!< DATA offset
#define SPI_DATA_RFU_OFST		16	//!< RFU offset


#define SPI_DATA_DATA_MASK	0x0000FFFF	//!< DATA mask
#define SPI_DATA_RFU_MASK		0xFFFF0000	//!< RFU mask

/* Enumeration of the different value for a bits field . We recommend to use
 * human readable value. */

#define SPI_DATA_DATA_DISABLE			//!< Data

/** @} */ /* @defgroup SPI_REGS_DR */
/** @defgroup SPI_REGS_CR Control Register (CR)
 *
 * @li SPIEN [0]	- R/W: SPI enable
 * @li MMEN [1]		- R/W: SPI master mode enable
 * @li WOR [2]		- R/W: wire-OR
 * @li CLKPOL [3]	- R/W: clock polarity
 * @li PHASE [4]	- R/W: phase select
 * @li BIRQ [5]		- R/W: BRG timer interrupt request
 * @li STR [6]		- R/W: start an SPI interrupt request
 * @li IRQE [7]		- R/W: interrupt request enable
 * @li RFU [31:8]	- R: reserved
 *
 * @{
 */

#define SPI_CR_OFST	0x00000004	//!< Register offset
#define SPI_CR_DFLT	0x00000000	//!< Register default value

/* Bits Fields */

#define SPI_CR_SPIEN_OFST		0	//!< SPIEN offset
#define SPI_CR_MMEN_OFST		1	//!< MMEN offset
#define SPI_CR_WOR_OFST		2	//!< WOR offset
#define SPI_CR_CLKPOL_OFST	3	//!< CLKPOL offset
#define SPI_CR_PHASE_OFST		4	//!< PHASE offset
#define SPI_CR_BIRQ_OFST		5	//!< BIRQ offset
#define SPI_CR_STR_OFST		6	//!< STR offset
#define SPI_CR_IRQE_OFST		7	//!< IRQE offset
#define SPI_CR_RFU_OFST		8	//!< RFU offset


#define SPI_CR_SPIEN_MASK		0x00000001	//!< SPIEN mask
#define SPI_CR_MMEN_MASK		0x00000002	//!< MMEN mask
#define SPI_CR_WOR_MASK		0x00000004	//!< WOR mask
#define SPI_CR_CLKPOL_MASK	0x00000008	//!< CLKPOL mask
#define SPI_CR_PHASE_MASK		0x00000010	//!< PHASE mask
#define SPI_CR_BIRQ_MASK		0x00000020	//!< BIRQ mask
#define SPI_CR_STR_MASK		0x00000040	//!< STR mask
#define SPI_CR_IRQE_MASK		0x00000080	//!< IRQE mask
#define SPI_CR_RFU_MASK		0xFFFFFF00	//!< RFU mask

/* Enumeration of the different value for a bits field . We recommend to use
 * human readable value. */

#define SPI_CR_SPIEN_DISABLE		0	//!< SPI disabled
#define SPI_CR_SPIEN_ENABLE		1	//!< SPI enabled

#define SPI_CR_MODE_SLAVE			0	//!< Slave mode
#define SPI_CR_MODE_MASTER		1	//!< Master mode

#define SPI_IO_OPEN_DRAIN_DISABLE	0	//!< SPI signals not configured
#define SPI_IO_OPEN_DRAIN_ENABLE	1	//!< SPI signals configured

#define SPI_CLOCK_POL_LOW			0	//!< polarity low
#define SPI_CLOCK_POL_HIGH		1	//!< polarity high

#define SPI_CLOCK_PHA_LOW			0	//!< sets the phase of the data to the clock
#define SPI_CLOCK_PHA_HIGH		1	//!<

#define SPI_CR_BIRQ_DISABLE		0	//!< SPIEN ='0' disable the baud rate generation else nothing
#define SPI_CR_BIRQ_ENABLE		1	//!< SPIEN ='0' enable the baud rate generation else nothing

#define SPI_CR_STR_1				1	//!< Sets IRQ='1'in the SPI_STAT

#define SPI_CR_IRQE_DISABLE		0	//!< interrupts disabled
#define SPI_CR_IRQE_ENABLE		1	//!< interrupts enable

/** @} */ /* @defgroup SPI_REGS_CR */

/** @defgroup SPI_REGS_SR Status Register (SR)
 *
 * @li SLAS [0]		- R: slave select
 * @li TXST [1]		- R: transmit status
 * @li TUND [2]		- R/W1C: transmit underrun
 * @li ROVR [3]		- R/W1C: receive overrun
 * @li ABT [4]		- R/W1C: slave mode transaction abort
 * @li COL [5]		- R/W1C: collision
 * @li TOVR [6]		- R/W1C: transmit overrun
 * @li IRQ [7]		- R/W1C: interrupt request
 * @li RFU [31:8]	- R/W1C: reserved
 *
 * @{
 */
#define SPI_SR_OFST	0x00000008	//!< Register offset
#define SPI_SR_DFLT	0x00000001	//!< Register default value

/* Bits Fields */

#define SPI_SR_SLAS_OFST		0	//!< SLAS offset
#define SPI_SR_TXST_OFST		1	//!< TXST offset
#define SPI_SR_TUND_OFST		2	//!< TUND offset
#define SPI_SR_ROVR_OFST		3	//!< ROVR offset
#define SPI_SR_ABT_OFST		4	//!< ABT offset
#define SPI_SR_COL_OFST		5	//!< COL offset
#define SPI_SR_TOVR_OFST		6	//!< TOVR offset
#define SPI_SR_IRQ_OFST		7	//!< IRQ offset
#define SPI_SR_RFU_OFST		8	//!< RFU offset


#define SPI_SR_SLAS_MASK		0x00000001	//!< SLAS mask
#define SPI_SR_TXST_MASK		0x00000002	//!< TXST mask
#define SPI_SR_TUND_MASK		0x00000004	//!< TUND mask
#define SPI_SR_ROVR_MASK		0x00000008	//!< ROVR mask
#define SPI_SR_ABT_MASK		0x00000010	//!< ABT mask
#define SPI_SR_COL_MASK		0x00000020	//!< COL mask
#define SPI_SR_TOVR_MASK		0x00000040	//!< TOVR mask
#define SPI_SR_IRQ_MASK		0x00000080	//!< IRQ mask
#define SPI_SR_RFU_MASK		0xFFFFFF00	//!< RFU mask


/* Enumeration of the different value for a bits field . We recommend to use
 * human readable value. */

#define SPI_CR_SLAS_0			0	//!< Slave selected (SPI=Slave)
#define SPI_CR_SLAS_1			1	//!< Slave not selected (SPI=Slave)

#define SPI_CR_TXST_0			0	//!< No data transmission
#define SPI_CR_TXST_1			1	//!< data transmission

#define SPI_CR_TUND_0			0	//!< error has not occurred
#define SPI_CR_TUND_1			1	//!< error has occurred

#define SPI_CR_ROVR_0			0	//!< error has not occurred
#define SPI_CR_ROVR_1			1	//!< error has occurred

#define SPI_CR_ABT_0			0	//!< Slave mode not detected
#define SPI_CR_ABT_1			1	//!< Slave mode detected

#define SPI_CR_COL_0			0	//!< fault mode not detected
#define SPI_CR_COL_1			1	//!< fault mode detected

#define SPI_CR_TOVR_0			0	//!< error has not occurred
#define SPI_CR_TOVR_1			1	//!< error has occurred

#define SPI_CR_IRQ_0			0	//!< SPI interrupt not pending
#define SPI_CR_IRQ_1			1	//!< SPI interrupt pending

/** @} */ /* @defgroup SPI_REGS_SR */

/** @defgroup SPI_REGS_MR MODE Register (MR)
 *
 * @li SSV [0]		- R/W: slave select value
 * @li SSIO [1]		- R/W: slave select I/O
 * @li NUMBITS [5:2]- R/W: number of Data Bits per Character to Transfer
 * @li DIAG [6]		- R/W: Diagnostic Mode Control
 * @li TX_LJ [7]	- R/W: Used when NUMBITS !=0
 * @li RFU [31:8]	- R: reserved
 *
 * @{
 */
#define SPI_MR_OFST	0x0000000C	//!< Register offset
#define SPI_MR_DFLT	0x00000000	//!< Register default value

/* Bits Fields */

#define SPI_MR_SSV_OFST		0	//!< SSV offset
#define SPI_MR_SSIO_OFST		1	//!< SSIO offset
#define SPI_MR_NUMBITS_OFST	2	//!< NUMBITS offset
#define SPI_MR_DIAG_OFST		6	//!< DIAG offset
#define SPI_MR_TX_LJ_OFST		7	//!< TX_LJ offset
#define SPI_MR_RFU_OFST		8	//!< RFU offset

#define SPI_MR_SSV_MASK		0x00000001	//!< SSV mask
#define SPI_MR_SSIO_MASK		0x00000002	//!< SSIO mask
#define SPI_MR_NUMBITS_MASK	0x0000003C	//!< NUMBITS mask
#define SPI_MR_DIAG_MASK		0x00000040	//!< DIAG mask
#define SPI_MR_TX_LJ_MASK		0x00000080	//!< TX_LJ mask
#define SPI_MR_RFU_MASK		0xFFFFFF00	//!< RFU mask


/* Enumeration of the different value for a bits field . We recommend to use
 * human readable value. */

#define SPI_MR_SSV_0		0	//!< SSV='0'(asserts nSS low)
#define SPI_MR_SSV_1		1	//!< SSV='1'(deasserts nSS low)

#define SPI_MR_SSIO_0		0	//!< nSS = input
#define SPI_MR_SSIO_1		1	//!< nSS = output

#define SPI_MR_NUMBITS_2	0	//!< the field contains the number of bits to shift for each character transfer

#define SPI_MR_DIAG_0		0	//!< return SPI_BRG
#define SPI_MR_DIAG_1		1	//!< return SPI Baud Rate Counter

#define SPI_MR_TX_LJ_0	0	//!< transmit data loaded from fifo
#define SPI_MR_TX_LJ_1	1	//!< transmit data is left justified as it is loaded

/** @} */ /* @defgroup SPI_REGS_MR */

/** @defgroup SPI_REGS_DSR Diagnostic State Register (DSR)
 *
 * @li SPISTATE [5:0]	- R: SPI state machine
 * @li TCKEN [6]		- R: transmit clock enable
 * @li SCKEN [7]		- R: shift clock enable
 * @li RFU [31:8]		- R: reserved
 * @{
 */
#define SPI_DSR_OFST	0x00000010	//!< Register offset
#define SPI_DSR_DFLT	0x00000000	//!< Register default value

/* Bits Fields */

#define SPI_DSR_SPISTATE_OFST	0	//!< SPISTATE offset
#define SPI_DSR_TCKEN_OFST	6	//!< TCKEN offset
#define SPI_DSR_SCKEN_OFST	7	//!< SCKEN offset
#define SPI_DSR_RFU_OFST		8	//!< RFU offset


#define SPI_DSR_SPISTATE_MASK	0x0000003F	//!< SPISTATE mask
#define SPI_DSR_TCKEN_MASK	0x00000040	//!< TCKEN mask
#define SPI_DSR_SCKEN_MASK	0x00000080	//!< SCKEN mask
#define SPI_DSR_RFU_MASK		0xFFFFFF00	//!< RFU mask


/* Enumeration of the different value for a bits field . We recommend to use
 * human readable value. */

#define SPI_DSR_SPISTATE_0	0	//!< define the current state

#define SPI_DSR_TCKEN_0		0	//!< transmit clock enable de-asserted
#define SPI_DSR_TCKEN_1		1	//!< transmit clock enable asserted

#define SPI_DSR_SCKEN_0		0	//!< shift clock enable de-asserted
#define SPI_DSR_SCKEN_1		1	//!< shift clock enable-asserted


/** @} */ /* @defgroup SPI_REGS_DSR */

/** @defgroup SPI_REGS_BRR Baud Rate Register (BRR)
 *
 * @li BRG [15:0]	- R/W: baud rate reload value
 * @li RFU [31:16]	- R: reserved
 * @{
 */
#define SPI_BRR_OFST	0x00000014	//!< Register offset
#define SPI_BRR_DFLT	0x0000FFFF	//!< Register default value

/* Bits Fields */

#define SPI_BRR_BRG_OFST	0	//!< BRG offset
#define SPI_BRR_RFU_OFST	16	//!< RFU offset


#define SPI_BRR_BRG_MASK	0x0000FFFF	//!< BRG mask
#define SPI_BRR_RFU_MASK	0xFFFF0000	//!< RFU mask



/* Enumeration of the different value for a bits field . We recommend to use
 * human readable value. */

#define SPI_BRR_BRG			//!< Baud rate reload value



/** @} */ /* @defgroup SPI_REGS_BRR */

/** @defgroup SPI_REGS_DMAR DMA register (DMAR)
 *
 * @li TX_FIFO_LEVEL [1:0]	- R/W: put the bit request threhold
 * @li RFU1 [3:2]			- R: reserved
 * @li TX_FIFO_CLR [4]		- W/O: reset the bit
 * @li RFU2 [7:5]			- R: reserved
 * @li TX_FIFO_CNT [10:8]	- R: number of entries
 * @li RFU3 [14:11]			- R: reserved
 * @li TX_DMA_EN [15]		- R/W: used to enable/disable the bit
 * @li RX_FIFO_LEVEL [17:16]- R/W: put the bit request threshold
 * @li RFU4 [19:18]			- R: reserved
 * @li RX_FIFO_CLR [20]		- W/O: reset the bit
 * @li RFU5 [23:21]			- R: reserved
 * @li RX_FIFO_CNT [26:24]	- R: number of entries
 * @li RFU6 [30:27]			- R: reserved
 * @li RX_DMA_EN [31]		- R/W: Enables DMA for receive
 * @{
 */
#define SPI_DMAR_OFST	0x00000018	//!< Register offset
#define SPI_DMAR_DFLT	0x00030003	//!< Register default value

/* Bits Fields */

#define SPI_DMAR_TX_FIFO_LEVEL_OFST	0	//!< TX_FIFO_LEVEL offset
#define SPI_DMAR_RFU1_OFST			2	//!< RFU1 offset
#define SPI_DMAR_TX_FIFO_CLR_OFST		4	//!< TX_FIFO_CLR offset
#define SPI_DMAR_RFU2_OFST			5	//!< RFU2 offset
#define SPI_DMAR_TX_FIFO_CNT_OFST		8	//!< TX_FIFO_CNT offset
#define SPI_DMAR_RFU3_OFST			11	//!< RFU3 offset
#define SPI_DMAR_TX_DMA_EN_OFST		15	//!< TX_DMA_EN offset
#define SPI_DMAR_RX_FIFO_LEVEL_OFST	16	//!< RX_FIFO_LEVEL offset
#define SPI_DMAR_RFU4_OFST			18	//!< RFU4 offset
#define SPI_DMAR_RX_FIFO_CLR_OFST		20	//!< RX_FIFO_CLR offset
#define SPI_DMAR_RFU5_OFST			21	//!< RFU5 offset
#define SPI_DMAR_RX_FIFO_CNT_OFST		24	//!< RX_FIFO_CNT offset
#define SPI_DMAR_RFU6_OFST			27	//!< RFU6 offset
#define SPI_DMAR_RX_DMA_EN_OFST		31	//!< RX_DMA_EN offset


#define SPI_DMAR_TX_FIFO_LEVEL_MASK	0x00000003	//!< TX_FIFO_LEVEL mask
#define SPI_DMAR_RFU1_MASK			0x0000000C	//!< RFU1 mask
#define SPI_DMAR_TX_FIFO_CLR_MASK		0x00000010	//!< TX_FIFO_CLR mask
#define SPI_DMAR_RFU2_MASK			0x000000E0	//!< RFU2 mask
#define SPI_DMAR_TX_FIFO_CNT_MASK		0x00000700	//!< TX_FIFO_CNT mask
#define SPI_DMAR_RFU3_MASK			0x00007800	//!< RFU3 mask
#define SPI_DMAR_TX_DMA_EN_MASK		0x00008000	//!< TX_DMA_EN mask
#define SPI_DMAR_RX_FIFO_LEVEL_MASKT	0x00030000	//!< RX_FIFO_LEVEL mask
#define SPI_DMAR_RFU4_MASK			0x000C0000	//!< RFU4 mask
#define SPI_DMAR_RX_FIFO_CLR_MASK		0x00100000	//!< RX_FIFO_CLR mask
#define SPI_DMAR_RFU5_MASK			0x00E00000	//!< RFU5 mask
#define SPI_DMAR_RX_FIFO_CNT_MASK		0x07000000	//!< RX_FIFO_CNT mask
#define SPI_DMAR_RFU6_MASK			0x78000000	//!< RFU6 mask
#define SPI_DMAR_RX_DMA_EN_MASK		0x80000000	//!< RX_DMA_EN mask

/* Enumeration of the different value for a bits field . We recommend to use
 * human readable value. */

#define SPI_DMAR_TX_FIFO_LEVEL_0		0	//!< 1 free entry
#define SPI_DMAR_TX_FIFO_LEVEL_1		1	//!< 2 free entries
#define SPI_DMAR_TX_FIFO_LEVEL_2		2	//!< 3 free entries
#define SPI_DMAR_TX_FIFO_LEVEL_3		3	//!< 4 free entries

#define SPI_DMAR_TX_FIFO_CLR_0		0	//!< Nothing
#define SPI_DMAR_TX_FIFO_CLR_1		1	//!< Reset

#define SPI_DMAR_TX_FIFO_CNT_0		0	//!< TxFIFO has 0 entries
#define SPI_DMAR_TX_FIFO_CNT_1		1	//!< TxFIFO has 1 entry
#define SPI_DMAR_TX_FIFO_CNT_2		2	//!< TxFIFO has 2 entries
#define SPI_DMAR_TX_FIFO_CNT_3		3	//!< TxFIFO has 3 entries
#define SPI_DMAR_TX_FIFO_CNT_4		4	//!< TxFIFO has 4 entries

#define SPI_DMAR_TX_DMA_EN_DISABLE	0	//!< TX DMA disable
#define SPI_DMAR_TX_DMA_EN_ENABLE		1	//!< TX DMA enable

#define SPI_DMAR_RX_FIFO_LEVEL_0		0	//!< request RxDMA when RxFIFO has 1 entry
#define SPI_DMAR_RX_FIFO_LEVEL_1		1	//!< request RxDMA when RxFIFO has 2 entries
#define SPI_DMAR_RX_FIFO_LEVEL_2		2	//!< request RxDMA when RxFIFO has 3 entries
#define SPI_DMAR_RX_FIFO_LEVEL_3		3	//!< request RxDMA when RxFIFO has 4 entries

#define SPI_DMAR_RX_FIFO_CLR_0		0	//!< Nothing
#define SPI_DMAR_RX_FIFO_CLR_1		1	//!< Reset

#define SPI_DMAR_RX_FIFO_CNT_0		0	//!< RxFIFO has 0 entries
#define SPI_DMAR_RX_FIFO_CNT_1		1	//!< RxFIFO has 1 entry
#define SPI_DMAR_RX_FIFO_CNT_2		2	//!< RxFIFO has 2 entries
#define SPI_DMAR_RX_FIFO_CNT_3		3	//!< RxFIFO has 3 entries
#define SPI_DMAR_RX_FIFO_CNT_4		4	//!< RxFIFO has 4 entries

#define SPI_DMAR_RX_DMA_EN_DISABLE		0	//!< RX DMA disable
#define SPI_DMAR_RX_DMA_EN_ENABLE			1	//!< RX DMA enable


/** @} */ /* @defgroup SPI_REGS_DMAR */

/** @defgroup SPI_REGS_MCR Mode Control Register (MCR)
 *
 * @li I2S_EN [0]	- R/W: I2S mode enable
 * @li I2S_MUTE [1]	- R/W: I2S mute transmit
 * @li I2S_PAUSE [2]- R/W: I2S pause transmit/receive
 * @li I2S_MONO [3]	- R/W: I2S mono audio mode
 * @li I2S_LJ [4]	- R/W: I2S left justify
 * @li RFU [31:5]	- R: reserved
 * @{
 */
#define SPI_MCR_OFST	0x0000001C	//!< Register offset
#define SPI_MCR_DFLT	0x00000000	//!< Register default value

/* Bits Fields */

#define SPI_MCR_I2S_EN_OFST		0	//!< I2S_EN offset
#define SPI_MCR_I2S_MUTE_OFST		1	//!< I2S_MUTE offset
#define SPI_MCR_I2S_PAUSE_OFST	2	//!< I2S_PAUSE offset
#define SPI_MCR_I2S_MONO_OFST		3	//!< I2S_MONO offset
#define SPI_MCR_I2S_LJ_OFST		4	//!< I2S_LJ offset
#define SPI_MCR_RFU_OFST			5	//!< RFU offset


#define SPI_MCR_I2S_EN_MASK		0x00000001	//!< I2S_EN mask
#define SPI_MCR_I2S_MUTE_MASK		0x00000002	//!< I2S_MUTE mask
#define SPI_MCR_I2S_PAUSE_MASK	0x00000004	//!< I2S_PAUSE mask
#define SPI_MCR_I2S_MONO_MASK		0x00000008	//!< I2S_MONO mask
#define SPI_MCR_I2S_LJ_MASK		0x00000010	//!< I2S_LJ mask
#define SPI_MCR_RFU_MASK			0xFFFFFFE0	//!< RFU mask



/* Enumeration of the different value for a bits field . We recommend to use
 * human readable value. */

#define SPI_MCR_I2S_EN_DISABLE	0	//!<disable mode
#define SPI_MCR_I2S_EN_ENABLE		1	//!<enable mode

#define SPI_MCR_I2S_MUTE_0		0	//!<normal transmit/receive
#define SPI_MCR_I2S_MUTE_1		1	//!<transmit '0'

#define SPI_MCR_I2S_PAUSEL_0		0	//!<normal transmit/receive
#define SPI_MCR_I2S_PAUSEL_1		1	//!<halt transmit and receive FIFO&DMA

#define SPI_MCR_I2S_MONO_0		0	//!<stereo mode
#define SPI_MCR_I2S_MONO_1		1	//!<mono mode

#define SPI_MCR_I2S_LJ_0			0	//!<normal I2S audio protocol
#define SPI_MCR_I2S_LJ_1			1	//!<audio data is in sync with nSS


/** @} */ /* @defgroup SPI_REGS_MCR */

#ifndef __ASSEMBLER__
/* -------------------------------------------------------------------------- */
/** SPI Registers.
 *
 */
typedef volatile struct _spi_regs_{
	unsigned dr;	//< data register
	unsigned cr;	//< control register
	unsigned sr;	//< status register
	unsigned mr;	//< mode register
	unsigned dsr;	//< diagnostic state register
	unsigned brr;	//< baud rate register
	unsigned dmar;	//< dma register
	unsigned mcr;	//< mode control register
} spi_regs_t;

#endif /* __ASSEMBLER__ */

/** @} */ /* @defgroup SPI_REGS */

#endif /* SPI_REGS_H_ */
