/*
 * trng_regs.h --
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2010, Maxim Integrated Products
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MAXIM INTEGRATED PRODUCTS ''AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MAXIM INTEGRATED PRODUCTS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* [INTERNAL] ------------------------------------------------------------------
 * Created on: June 8, 2010
 * Author: Gregory Romé <gregory.rome@maxim-ic.com>
 *
 * ---- Subversion keywords (need to set the keyword property)
 * $Revision:: 21       $:  Revision of last commit
 * $Author:: ray.vandew#$:  Author of last commit
 * $Date:: 2013-06-07 1#$:  Date of last commit
 * [/INTERNAL] -------------------------------------------------------------- */

#ifndef TRNG_REGS_H_
#define TRNG_REGS_H_

/** @file trng_regs.h TRNG Registers Header */

/** @defgroup TRNG TRNG Driver
 * @ingroup DRIVER
 */

/** @defgroup TRNG_REGS TRNG Registers
 *
 * @note TRNG IP or Specification version number
 *
 * @ingroup TRNG
 * @{
 */

/** @defgroup TRNG_REGS_AR TRNG A Register
 *
 * @li BF1 [2:0] - R/W: Bits field 1
 * @li BF2 [5] - R/W: Bits field 2
 * @li BF3 [6] - R/W: Bits field 3
 *
 * @{
 */

#define TRNG_AR_OFST	0x0	//!< A Register offset
#define TRNG_AR_DFLT	0x0	//!< A Register default value

/* Bits Fields */

#define TRNG_AR_BF1_OFST	0	//!< BF1 offset
#define TRNG_AR_BF2_OFST	5	//!< BF2 offset
#define TRNG_AR_BF3_OFST	6	//!< BF3 offset

#define TRNG_AR_BF1_MASK	0x7	//!< BF1 mask
#define TRNG_AR_BF2_MASK	0x1	//!< BF2 mask
#define TRNG_AR_BF3_MASK	0x1	//!< BF3 mask

/* Enumeration of the different value for a bits field . We recommend to use
 * human readable value. */

#define TRNG_AR_BF1_OPTION1		0x0	//!< BF1 value 1
#define TRNG_AR_BF1_OPTION2		0x3	//!< BF1 value 2
#define TRNG_AR_BF1_OPTION3		0x7	//!< BF1 value 3

/* We use the term enabled/disabled for bits field of size 1 */
#define TRNG_AR_BF2_ENABLED	0x1	//!< BF2 enabled == 1

#define TRNG_AR_BF3_DISABLED	0x1	//!< BF3 enabled == 0

/** @} */ /* @defgroup TRNG_REGS_AR */

/** @defgroup TRNG_REGS_BR TRNG B Register
 * @{
 */

#define TRNG_BR_OFST	0x0	//!< B Register offset
#define TRNG_BR_DFLT	0x0	//!< A Register default value

/* Bits Fields */



/** @} */ /* @defgroup TRNG_REGS_BR */


#ifndef __ASSEMBLER__
/* -------------------------------------------------------------------------- */
/** TRNG Registers.
 *
 */
typedef volatile struct _trng_regs_{
	//volatile unsigned ar;	//< A register
	//volatile unsigned br;	//< B register
        volatile unsigned                       trngcr; //< TRNGCR register
        volatile unsigned                       trngdr; //< TRNGDR register
} trng_regs_t;

#endif /* __ASSEMBLER__ */

/** @} */ /* @defgroup TRNG_REGS */

#endif /* TRNG_REGS_H_ */
